@@ -189,7 +189,7 @@ send_component_dialog (GtkWindow *parent, ECalClient *client, ECalComponent *com
 	content_area = e_alert_dialog_get_content_area (E_ALERT_DIALOG (dialog));
 
 	if (strip_alarms)
-		sa_checkbox = add_checkbox (GTK_BOX (content_area), _("Send my alarms with this event"));
+		sa_checkbox = add_checkbox (GTK_BOX (content_area), _("Send my reminders with this event"));
 	if (only_new_attendees)
 		ona_checkbox = add_checkbox (GTK_BOX (content_area), _("Notify new attendees _only"));
 
