@@ -24,18 +24,38 @@
 #ifndef __E_CAL_CONFIG_H__
 #define __E_CAL_CONFIG_H__
 
-#include <glib-object.h>
-
-#include <libecal/e-cal.h>
+#include <libecal/e-cal-client.h>
 #include "e-util/e-config.h"
 
+/* Standard GObject macros */
+#define E_TYPE_CAL_CONFIG \
+	(e_cal_config_get_type ())
+#define E_CAL_CONFIG(obj) \
+	(G_TYPE_CHECK_INSTANCE_CAST \
+	((obj), E_TYPE_CAL_CONFIG, ECalConfig))
+#define E_CAL_CONFIG_CLASS(cls) \
+	(G_TYPE_CHECK_CLASS_CAST \
+	((cls), E_TYPE_CAL_CONFIG, ECalConfigClass))
+#define E_IS_CAL_CONFIG(obj) \
+	(G_TYPE_CHECK_INSTANCE_TYPE \
+	((obj), E_TYPE_CAL_CONFIG))
+#define E_IS_CAL_CONFIG_CLASS(cls) \
+	(G_TYPE_CHECK_CLASS_TYPE \
+	((cls), E_TYPE_CAL_CONFIG))
+#define E_CAL_CONFIG_GET_CLASS(obj) \
+	(G_TYPE_INSTANCE_GET_CLASS \
+	((obj), E_TYPE_CAL_CONFIG, ECalConfigClass))
+
 G_BEGIN_DECLS
 
 typedef struct _ECalConfig ECalConfig;
 typedef struct _ECalConfigClass ECalConfigClass;
+typedef struct _ECalConfigPrivate ECalConfigPrivate;
 
 struct _ECalConfig {
 	EConfig config;
+
+	ECalConfigPrivate *priv;
 };
 
 struct _ECalConfigClass {
@@ -54,7 +74,7 @@ struct _ECalConfigTargetSource {
 	EConfigTarget target;
 
 	struct _ESource *source;
-        ECalSourceType source_type;
+        ECalClientSourceType source_type;
 };
 
 struct _ECalConfigTargetPrefs {
@@ -65,11 +85,14 @@ struct _ECalConfigTargetPrefs {
 
 typedef struct _EConfigItem ECalConfigItem;
 
-GType e_cal_config_get_type (void);
-ECalConfig *e_cal_config_new (gint type, const gchar *menuid);
-
-ECalConfigTargetSource *e_cal_config_target_new_source (ECalConfig *ecp, struct _ESource *source);
-ECalConfigTargetPrefs *e_cal_config_target_new_prefs (ECalConfig *ecp);
+GType		e_cal_config_get_type (void);
+ECalConfig *	e_cal_config_new		(gint type,
+						 const gchar *menuid);
+ECalConfigTargetSource *
+		e_cal_config_target_new_source	(ECalConfig *ecp,
+						 ESource *source);
+ECalConfigTargetPrefs *
+		e_cal_config_target_new_prefs	(ECalConfig *ecp);
 
 G_END_DECLS
 
