@@ -20,12 +20,15 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "ea-cal-view.h"
 #include "ea-calendar-helpers.h"
 #include "e-day-view.h"
 #include "e-week-view.h"
-#include "goto.h"
-#include <glib.h>
+#include "dialogs/goto-dialog.h"
 #include <glib/gi18n.h>
 
 static void ea_cal_view_class_init (EaCalViewClass *klass);
@@ -46,11 +49,11 @@ static void ea_cal_view_dates_change_cb (GnomeCalendar *gcal, gpointer data);
 static void atk_action_interface_init (AtkActionIface *iface);
 static gboolean action_interface_do_action (AtkAction *action, gint i);
 static gint action_interface_get_n_actions (AtkAction *action);
-static G_CONST_RETURN gchar *
+static const gchar *
 action_interface_get_description (AtkAction *action, gint i);
-static G_CONST_RETURN gchar *
+static const gchar *
 action_interface_get_keybinding (AtkAction *action, gint i);
-static G_CONST_RETURN gchar *
+static const gchar *
 action_interface_action_get_name (AtkAction *action, gint i);
 
 static gpointer parent_class = NULL;
@@ -171,7 +174,6 @@ static AtkObject*
 ea_cal_view_get_parent (AtkObject *accessible)
 {
 	ECalendarView *cal_view;
-	GnomeCalendar *gnomeCalendar;
 	GtkWidget *widget;
 
 	g_return_val_if_fail (EA_IS_CAL_VIEW (accessible), NULL);
@@ -181,9 +183,8 @@ ea_cal_view_get_parent (AtkObject *accessible)
 		return NULL;
 
 	cal_view = E_CALENDAR_VIEW (widget);
-	gnomeCalendar = e_calendar_view_get_calendar (cal_view);
 
-	return gtk_widget_get_accessible (GTK_WIDGET (gnomeCalendar));
+	return gtk_widget_get_accessible (gtk_widget_get_parent (GTK_WIDGET (cal_view)));
 }
 
 static void
@@ -205,7 +206,7 @@ ea_cal_view_event_changed_cb (ECalendarView *cal_view, ECalendarViewEvent *event
 	}
 	else if ((E_IS_WEEK_VIEW (cal_view)) && event) {
 		EWeekViewEventSpan *span;
-		EWeekViewEvent *week_view_event = (EWeekViewEvent *)event;
+		EWeekViewEvent *week_view_event = (EWeekViewEvent *) event;
 		EWeekView *week_view = E_WEEK_VIEW (cal_view);
 		/* get the first span of the event */
 		span = &g_array_index (week_view->spans, EWeekViewEventSpan,
@@ -243,7 +244,7 @@ ea_cal_view_event_added_cb (ECalendarView *cal_view, ECalendarViewEvent *event,
 	}
 	else if ((E_IS_WEEK_VIEW (cal_view)) && event) {
 		EWeekViewEventSpan *span;
-		EWeekViewEvent *week_view_event = (EWeekViewEvent *)event;
+		EWeekViewEvent *week_view_event = (EWeekViewEvent *) event;
 		EWeekView *week_view = E_WEEK_VIEW (cal_view);
 		/* get the first span of the event */
 		span = &g_array_index (week_view->spans, EWeekViewEventSpan,
@@ -379,13 +380,13 @@ action_interface_get_n_actions (AtkAction *action)
 	return CAL_VIEW_ACTION_NUM;
 }
 
-static G_CONST_RETURN gchar *
+static const gchar *
 action_interface_get_description (AtkAction *action, gint index)
 {
 	return action_interface_action_get_name (action, index);
 }
 
-static G_CONST_RETURN gchar *
+static const gchar *
 action_interface_get_keybinding (AtkAction *action, gint index)
 {
 	GtkWidget *widget;
@@ -422,7 +423,7 @@ action_interface_get_keybinding (AtkAction *action, gint index)
 	 return NULL;
 }
 
-static G_CONST_RETURN gchar *
+static const gchar *
 action_interface_action_get_name (AtkAction *action, gint i)
 {
 	if (i >= 0 && i < CAL_VIEW_ACTION_NUM)
