@@ -21,12 +21,16 @@
  * Copyright (C) 2009 Intel Corporation
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "e-alert-dialog.h"
 
 #include "e-util.h"
 
 struct _EAlertDialogPrivate {
-	GtkWindow *parent;
+	GtkWidget *content_area;  /* not referenced */
 	EAlert *alert;
 };
 
@@ -184,6 +188,7 @@ alert_dialog_constructed (GObject *object)
 
 	widget = gtk_vbox_new (FALSE, 12);
 	gtk_box_pack_start (GTK_BOX (container), widget, FALSE, FALSE, 0);
+	dialog->priv->content_area = widget;
 	gtk_widget_show (widget);
 
 	container = widget;
@@ -334,7 +339,7 @@ e_alert_run_dialog_for_args (GtkWindow *parent,
 
 /**
  * e_alert_dialog_get_alert:
- * @dialog: a #EAlertDialog
+ * @dialog: an #EAlertDialog
  *
  * Returns the #EAlert associated with @dialog.
  *
@@ -347,3 +352,21 @@ e_alert_dialog_get_alert (EAlertDialog *dialog)
 
 	return dialog->priv->alert;
 }
+
+/**
+ * e_alert_dialog_get_content_area:
+ * @dialog: an #EAlertDialog
+ *
+ * Returns the vertical box containing the primary and secondary labels.
+ * Use this to pack additional widgets into the dialog with the proper
+ * horizontal alignment (maintaining the left margin below the image).
+ *
+ * Returns: the content area #GtkBox
+ **/
+GtkWidget *
+e_alert_dialog_get_content_area (EAlertDialog *dialog)
+{
+	g_return_val_if_fail (E_IS_ALERT_DIALOG (dialog), NULL);
+
+	return dialog->priv->content_area;
+}
