@@ -21,9 +21,12 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "e-signature-list.h"
 
-#include <config.h>
 #include <string.h>
 
 #include <libedataserver/e-uid.h>
@@ -240,7 +243,7 @@ gconf_signatures_changed (GConfClient *client,
 static gpointer
 copy_func (gconstpointer data, gpointer closure)
 {
-	GObject *object = (GObject *)data;
+	GObject *object = (GObject *) data;
 
 	g_object_ref (object);
 
