@@ -47,10 +47,6 @@
 #define localtime_r(tp,tmp) memcpy(tmp,localtime(tp),sizeof(struct tm))
 #endif
 
-#define E_FILTER_DATESPEC_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_FILTER_DATESPEC, EFilterDatespecPrivate))
-
 #define d(x)
 
 typedef struct {
@@ -166,20 +162,20 @@ set_button (EFilterDatespec *fds)
 		break;
 	}
 
-	gtk_label_set_text ((GtkLabel *)fds->priv->label_button, label);
+	gtk_label_set_text ((GtkLabel *) fds->priv->label_button, label);
 }
 
 static void
 get_values (EFilterDatespec *fds)
 {
-	EFilterDatespecPrivate *p = E_FILTER_DATESPEC_GET_PRIVATE (fds);
+	EFilterDatespecPrivate *p = fds->priv;
 
 	switch (fds->priv->type) {
 	case FDST_SPECIFIED: {
 		guint year, month, day;
 		struct tm tm;
 
-		gtk_calendar_get_date ((GtkCalendar *)p->calendar_specify, &year, &month, &day);
+		gtk_calendar_get_date ((GtkCalendar *) p->calendar_specify, &year, &month, &day);
 		memset (&tm, 0, sizeof (tm));
 		tm.tm_mday = day;
 		tm.tm_year = year - 1900;
@@ -191,7 +187,7 @@ get_values (EFilterDatespec *fds)
 	case FDST_X_AGO: {
 		gint val;
 
-		val = gtk_spin_button_get_value_as_int ((GtkSpinButton *)p->spin_relative);
+		val = gtk_spin_button_get_value_as_int ((GtkSpinButton *) p->spin_relative);
 		fds->value = timespans[p->span].seconds * val;
 		break; }
 	case FDST_NOW:
@@ -207,7 +203,7 @@ set_values (EFilterDatespec *fds)
 {
 	gint note_type;
 
-	EFilterDatespecPrivate *p = E_FILTER_DATESPEC_GET_PRIVATE (fds);
+	EFilterDatespecPrivate *p = fds->priv;
 
 	p->type = fds->type==FDST_UNKNOWN ? FDST_NOW : fds->type;
 
@@ -223,19 +219,19 @@ set_values (EFilterDatespec *fds)
 		struct tm tm;
 
 		localtime_r (&fds->value, &tm);
-		gtk_calendar_select_month ((GtkCalendar*)p->calendar_specify, tm.tm_mon, tm.tm_year + 1900);
-		gtk_calendar_select_day ((GtkCalendar*)p->calendar_specify, tm.tm_mday);
+		gtk_calendar_select_month ((GtkCalendar*) p->calendar_specify, tm.tm_mon, tm.tm_year + 1900);
+		gtk_calendar_select_day ((GtkCalendar*) p->calendar_specify, tm.tm_mday);
 		break;
 	}
 	case FDST_X_AGO:
 		p->span = get_best_span (fds->value);
-		gtk_spin_button_set_value ((GtkSpinButton*)p->spin_relative, fds->value/timespans[p->span].seconds);
+		gtk_spin_button_set_value ((GtkSpinButton*) p->spin_relative, fds->value/timespans[p->span].seconds);
 		gtk_combo_box_set_active (GTK_COMBO_BOX (p->combobox_relative), p->span);
 		gtk_combo_box_set_active (GTK_COMBO_BOX (p->combobox_past_future), 0);
 		break;
 	case FDST_X_FUTURE:
 		p->span = get_best_span (fds->value);
-		gtk_spin_button_set_value ((GtkSpinButton*)p->spin_relative, fds->value/timespans[p->span].seconds);
+		gtk_spin_button_set_value ((GtkSpinButton*) p->spin_relative, fds->value/timespans[p->span].seconds);
 		gtk_combo_box_set_active (GTK_COMBO_BOX (p->combobox_relative), p->span);
 		gtk_combo_box_set_active (GTK_COMBO_BOX (p->combobox_past_future), 1);
 		break;
@@ -270,7 +266,7 @@ set_combobox_past_future (GtkComboBox *combobox, EFilterDatespec *fds)
 static void
 button_clicked (GtkButton *button, EFilterDatespec *fds)
 {
-	EFilterDatespecPrivate *p = E_FILTER_DATESPEC_GET_PRIVATE (fds);
+	EFilterDatespecPrivate *p = fds->priv;
 	GtkWidget *content_area;
 	GtkWidget *toplevel;
 	GtkDialog *dialog;
@@ -310,7 +306,7 @@ button_clicked (GtkButton *button, EFilterDatespec *fds)
 		set_button (fds);
 	}
 
-	gtk_widget_destroy ((GtkWidget *)dialog);
+	gtk_widget_destroy ((GtkWidget *) dialog);
 }
 
 static gboolean
@@ -386,10 +382,10 @@ filter_datespec_xml_decode (EFilterElement *element,
 	while (n) {
 		if (!strcmp ((gchar *)n->name, "datespec")) {
 			val = xmlGetProp (n, (xmlChar *)"type");
-			fds->type = atoi ((gchar *)val);
+			fds->type = atoi ((gchar *) val);
 			xmlFree (val);
 			val = xmlGetProp (n, (xmlChar *)"value");
-			fds->value = atoi ((gchar *)val);
+			fds->value = atoi ((gchar *) val);
 			xmlFree (val);
 			break;
 		}
@@ -436,12 +432,30 @@ filter_datespec_format_sexp (EFilterElement *element,
 		g_string_append_printf (out, "%d", (gint) fds->value);
 		break;
 	case FDST_X_AGO:
-		g_string_append_printf (
-			out, "(- (get-current-date) %d)", (gint) fds->value);
+		switch (get_best_span (fds->value)) {
+		case 5: /* months */
+			g_string_append_printf (out, "(get-relative-months (- 0 %d))", (gint) (fds->value / timespans[5].seconds));
+			break;
+		case 6: /* years */
+			g_string_append_printf (out, "(get-relative-months (- 0 %d))", (gint) (12 * fds->value / timespans[6].seconds));
+			break;
+		default:
+			g_string_append_printf (out, "(- (get-current-date) %d)", (gint) fds->value);
+			break;
+		}
 		break;
 	case FDST_X_FUTURE:
-		g_string_append_printf (
-			out, "(+ (get-current-date) %d)", (gint) fds->value);
+		switch (get_best_span (fds->value)) {
+		case 5: /* months */
+			g_string_append_printf (out, "(get-relative-months %d)", (gint) (fds->value / timespans[5].seconds));
+			break;
+		case 6: /* years */
+			g_string_append_printf (out, "(get-relative-months %d)", (gint) (12 * fds->value / timespans[6].seconds));
+			break;
+		default:
+			g_string_append_printf (out, "(+ (get-current-date) %d)", (gint) fds->value);
+			break;
+		}
 		break;
 	}
 }
@@ -465,7 +479,8 @@ e_filter_datespec_class_init (EFilterDatespecClass *class)
 static void
 e_filter_datespec_init (EFilterDatespec *datespec)
 {
-	datespec->priv = E_FILTER_DATESPEC_GET_PRIVATE (datespec);
+	datespec->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		datespec, E_TYPE_FILTER_DATESPEC, EFilterDatespecPrivate);
 	datespec->type = FDST_UNKNOWN;
 }
 
