@@ -22,7 +22,9 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
 
 #include <string.h>
 #include <sys/types.h>
@@ -31,7 +33,6 @@
 #include <fcntl.h>
 #include <errno.h>
 
-#include <glib.h>
 #include <glib/gstdio.h>
 
 #include <gtk/gtk.h>
@@ -101,7 +102,7 @@ new_rule_response (GtkWidget *dialog,
 		}
 
 		if (e_rule_context_find_rule (context, rule->name, rule->source)) {
-			e_alert_run_dialog_for_args ((GtkWindow *)dialog,
+			e_alert_run_dialog_for_args ((GtkWindow *) dialog,
 						     "filter:bad-name-notunique",
 						     rule->name, NULL);
 
@@ -169,20 +170,20 @@ rule_context_finalize (GObject *obj)
 {
 	ERuleContext *context =(ERuleContext *) obj;
 
-	g_list_foreach (context->rule_set_list, (GFunc)free_rule_set, NULL);
+	g_list_foreach (context->rule_set_list, (GFunc) free_rule_set, NULL);
 	g_list_free (context->rule_set_list);
 	g_hash_table_destroy (context->rule_set_map);
 
-	g_list_foreach (context->part_set_list, (GFunc)free_part_set, NULL);
+	g_list_foreach (context->part_set_list, (GFunc) free_part_set, NULL);
 	g_list_free (context->part_set_list);
 	g_hash_table_destroy (context->part_set_map);
 
 	g_free (context->error);
 
-	g_list_foreach (context->parts, (GFunc)g_object_unref, NULL);
+	g_list_foreach (context->parts, (GFunc) g_object_unref, NULL);
 	g_list_free (context->parts);
 
-	g_list_foreach (context->rules, (GFunc)g_object_unref, NULL);
+	g_list_foreach (context->rules, (GFunc) g_object_unref, NULL);
 	g_list_free (context->rules);
 
 	G_OBJECT_CLASS (e_rule_context_parent_class)->finalize (obj);
@@ -253,7 +254,8 @@ rule_context_load (ERuleContext *context,
 				}
 				rule = rule->next;
 			}
-		} else if ((rule_map = g_hash_table_lookup (context->rule_set_map, set->name))) {
+		} else if ((rule_map = g_hash_table_lookup (
+				context->rule_set_map, set->name))) {
 			rule = set->children;
 			while (rule) {
 				if (!strcmp ((gchar *)rule->name, "rule")) {
@@ -327,7 +329,7 @@ rule_context_save (ERuleContext *context,
 	l = context->rule_set_list;
 	while (l) {
 		map = l->data;
-		rules = xmlNewDocNode (doc, NULL, (xmlChar *)map->name, NULL);
+		rules = xmlNewDocNode (doc, NULL, (xmlChar *) map->name, NULL);
 		xmlAddChild (root, rules);
 		rule = NULL;
 		while ((rule = map->next (context, rule, NULL))) {
@@ -365,7 +367,9 @@ rule_context_revert (ERuleContext *context,
 		/* clear out anythign we have? */
 		return 0;
 
-	source_hash = g_hash_table_new ((GHashFunc)source_hashf, (GCompareFunc)source_eqf);
+	source_hash = g_hash_table_new (
+		(GHashFunc) source_hashf,
+		(GCompareFunc) source_eqf);
 
 	/* setup stuff we have now */
 	/* Note that we assume there is only 1 set of rules in a given rule context,
@@ -395,16 +399,26 @@ rule_context_revert (ERuleContext *context,
 						rule_map->type, NULL, NULL));
 
 					if (e_filter_rule_xml_decode (part, rule, context) == 0) {
-						/* use the revert data to keep track of the right rank of this rule part */
+						/* Use the revert data to keep
+						 * track of the right rank of
+						 * this rule part. */
 						rest_data = g_hash_table_lookup (source_hash, part->source);
 						if (rest_data == NULL) {
 							rest_data = g_malloc0 (sizeof (*rest_data));
-							rest_data->rules = g_hash_table_new (g_str_hash, g_str_equal);
-							g_hash_table_insert (source_hash, part->source, rest_data);
+							rest_data->rules = g_hash_table_new (
+								g_str_hash,
+								g_str_equal);
+							g_hash_table_insert (
+								source_hash,
+								part->source,
+								rest_data);
 						}
-						frule = g_hash_table_lookup (rest_data->rules, part->name);
+						frule = g_hash_table_lookup (
+							rest_data->rules,
+							part->name);
 						if (frule) {
-							if (context->priv->frozen == 0 && !e_filter_rule_eq (frule, part))
+							if (context->priv->frozen == 0 &&
+							    !e_filter_rule_eq (frule, part))
 								e_filter_rule_copy (frule, part);
 
 							g_object_unref (part);
@@ -415,7 +429,11 @@ rule_context_revert (ERuleContext *context,
 							g_hash_table_remove (rest_data->rules, frule->name);
 						} else {
 							e_rule_context_add_rule (context, part);
-							e_rule_context_rank_rule (context, part, part->source, rest_data->rank);
+							e_rule_context_rank_rule (
+								context,
+								part,
+								part->source,
+								rest_data->rank);
 						}
 						rest_data->rank++;
 					} else {
@@ -432,7 +450,7 @@ rule_context_revert (ERuleContext *context,
 	xmlFreeDoc (userdoc);
 
 	/* remove any we still have that weren't in the file */
-	g_hash_table_foreach (source_hash, (GHFunc)revert_source_remove, context);
+	g_hash_table_foreach (source_hash, (GHFunc) revert_source_remove, context);
 	g_hash_table_destroy (source_hash);
 
 	return 0;
