@@ -19,6 +19,10 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "e-mail-store.h"
 
 #include <glib/gi18n.h>
@@ -100,7 +104,7 @@ store_info_ref (StoreInfo *store_info)
 	g_return_val_if_fail (store_info != NULL, store_info);
 	g_return_val_if_fail (store_info->ref_count > 0, store_info);
 
-	g_atomic_int_add (&store_info->ref_count, 1);
+	g_atomic_int_inc (&store_info->ref_count);
 
 	return store_info;
 }
@@ -111,19 +115,19 @@ store_info_unref (StoreInfo *store_info)
 	g_return_if_fail (store_info != NULL);
 	g_return_if_fail (store_info->ref_count > 0);
 
-	if (g_atomic_int_exchange_and_add (&store_info->ref_count, -1) > 1)
-		return;
+	if (g_atomic_int_dec_and_test (&store_info->ref_count)) {
 
-	g_object_unref (store_info->store);
-	g_free (store_info->display_name);
+		g_object_unref (store_info->store);
+		g_free (store_info->display_name);
 
-	if (store_info->vtrash != NULL)
-		g_object_unref (store_info->vtrash);
+		if (store_info->vtrash != NULL)
+			g_object_unref (store_info->vtrash);
 
-	if (store_info->vjunk != NULL)
-		g_object_unref (store_info->vjunk);
+		if (store_info->vjunk != NULL)
+			g_object_unref (store_info->vjunk);
 
-	g_slice_free (StoreInfo, store_info);
+		g_slice_free (StoreInfo, store_info);
+	}
 }
 
 static void
@@ -235,67 +239,15 @@ mail_store_load_accounts (EMailSession *session,
 	account_list = e_get_account_list ();
 
 	for (iter = e_list_get_iterator ((EList *) account_list);
-		e_iterator_is_valid (iter); e_iterator_next (iter)) {
-
+	     e_iterator_is_valid (iter); e_iterator_next (iter)) {
 		EAccount *account;
-		CamelURL *url;
-		gchar *transport_uid;
-		gboolean skip = FALSE;
-		GError *error = NULL;
 
 		account = (EAccount *) e_iterator_get (iter);
 
 		if (!account->enabled)
 			continue;
 
-		/* Do not add local-delivery files,
-		 * but make them ready for later use. */
-		url = camel_url_new (account->source->url, NULL);
-		if (url != NULL) {
-			skip = em_utils_is_local_delivery_mbox_file (url);
-			camel_url_free (url);
-		}
-
-		if (skip) {
-			GError *error = NULL;
-
-			camel_session_add_service (
-				CAMEL_SESSION (session),
-				account->uid, account->source->url,
-				CAMEL_PROVIDER_STORE, &error);
-
-			if (error != NULL) {
-				g_warning (
-					"Failed to add '%s' as store: %s",
-					account->source->url,
-					error->message);
-				g_error_free (error);
-			}
-		} else {
-			e_mail_store_add_by_account (session, account);
-		}
-
-		/* While we're at it, add the account's transport to the
-		 * CamelSession.  The transport's UID is a kludge for now.
-		 * We take the EAccount's UID and tack on "-transport". */
-
-		if (account->transport == NULL)
-			continue;
-
-		transport_uid = g_strconcat (
-			account->uid, "-transport", NULL);
-
-		camel_session_add_service (
-			CAMEL_SESSION (session),
-			transport_uid, account->transport->url,
-			CAMEL_PROVIDER_TRANSPORT, &error);
-
-		g_free (transport_uid);
-
-		if (error != NULL) {
-			g_warning ("%s", error->message);
-			g_error_free (error);
-		}
+		e_mail_store_add_by_account (session, account);
 	}
 
 	g_object_unref (iter);
@@ -342,8 +294,10 @@ CamelStore *
 e_mail_store_add_by_account (EMailSession *session,
                              EAccount *account)
 {
-	CamelService *service;
+	CamelService *service = NULL;
 	CamelProvider *provider;
+	CamelURL *url;
+	gboolean skip;
 	GError *error = NULL;
 
 	g_return_val_if_fail (E_IS_MAIL_SESSION (session), NULL);
@@ -353,18 +307,57 @@ e_mail_store_add_by_account (EMailSession *session,
 	 * and if this belongs in the folder tree model, add it. */
 
 	provider = camel_provider_get (account->source->url, &error);
-	if (provider == NULL)
-		goto fail;
+	if (provider == NULL) {
+	/* In case we do not have a provider here, we handle
+	 * the special case of having multiple mail identities
+	 * eg. a dummy account having just SMTP server defined */
+		goto handle_transport;
+	}
 
 	service = camel_session_add_service (
 		CAMEL_SESSION (session),
 		account->uid, account->source->url,
 		CAMEL_PROVIDER_STORE, &error);
 
+handle_transport:
+
+	if (account->transport) {
+		/* While we're at it, add the account's transport to the
+		 * CamelSession.  The transport's UID is a kludge for now.
+		 * We take the EAccount's UID and tack on "-transport". */
+		gchar *transport_uid;
+		GError *transport_error = NULL;
+
+		transport_uid = g_strconcat (
+			account->uid, "-transport", NULL);
+
+		camel_session_add_service (
+			CAMEL_SESSION (session),
+			transport_uid, account->transport->url,
+			CAMEL_PROVIDER_TRANSPORT, &transport_error);
+
+		g_free (transport_uid);
+
+		if (transport_error) {
+			g_warning (
+				"%s: Failed to add transport service: %s",
+				G_STRFUNC, transport_error->message);
+			g_error_free (transport_error);
+		}
+	}
+
 	if (!CAMEL_IS_STORE (service))
 		goto fail;
 
-	if (provider->flags & CAMEL_PROVIDER_IS_STORAGE)
+	/* Do not add local-delivery files,
+	 * but make them ready for later use. */
+	url = camel_url_new (account->source->url, NULL);
+	if (url != NULL) {
+		skip = em_utils_is_local_delivery_mbox_file (url);
+		camel_url_free (url);
+	}
+
+	if (!skip && (provider->flags & CAMEL_PROVIDER_IS_STORAGE))
 		e_mail_store_add (
 			session, CAMEL_STORE (service), account->name);
 
