@@ -29,31 +29,34 @@
 #include <e-util/e-util.h>
 #include <e-util/e-account-utils.h>
 
+#include "e-mail-folder-utils.h"
 #include "em-folder-tree.h"
 #include "em-folder-selector.h"
 #include "em-utils.h"
 
 #include "em-folder-selection-button.h"
 
+#define EM_FOLDER_SELECTION_BUTTON_GET_PRIVATE(obj) \
+	(G_TYPE_INSTANCE_GET_PRIVATE \
+	((obj), EM_TYPE_FOLDER_SELECTION_BUTTON, EMFolderSelectionButtonPrivate))
+
 struct _EMFolderSelectionButtonPrivate {
-	EMailSession *session;
+	EMailBackend *backend;
 	GtkWidget *icon;
 	GtkWidget *label;
-
-	gchar *uri;  /* for single-select mode */
-	GList *uris; /* for multi-select mode */
+	EAccount *account;
 
 	gchar *title;
 	gchar *caption;
-
-	gboolean multiple_select;
+	gchar *folder_uri;
 };
 
 enum {
 	PROP_0,
+	PROP_ACCOUNT,
+	PROP_BACKEND,
 	PROP_CAPTION,
-	PROP_MULTISELECT,
-	PROP_SESSION,
+	PROP_FOLDER_URI,
 	PROP_TITLE
 };
 
@@ -82,33 +85,46 @@ folder_selection_button_unselected (EMFolderSelectionButton *button)
 static void
 folder_selection_button_set_contents (EMFolderSelectionButton *button)
 {
+	EMailBackend *backend;
+	CamelStore *store = NULL;
 	EAccount *account;
 	GtkLabel *label;
-	const gchar *uri;
-	gchar *folder_name;
+	const gchar *uid;
+	gchar *folder_name = NULL;
 
-	uri = button->priv->uri;
 	label = GTK_LABEL (button->priv->label);
-	folder_name = em_utils_folder_name_from_uri (uri);
+	backend = em_folder_selection_button_get_backend (button);
 
-	if (folder_name == NULL) {
+	if (backend != NULL && button->priv->folder_uri != NULL) {
+		EMailSession *session;
+
+		session = e_mail_backend_get_session (backend);
+		e_mail_folder_uri_parse (
+			CAMEL_SESSION (session),
+			button->priv->folder_uri,
+			&store, &folder_name, NULL);
+	}
+
+	if (store == NULL || folder_name == NULL) {
 		folder_selection_button_unselected (button);
 		return;
 	}
 
-	account = e_get_account_by_source_url (uri);
+	uid = camel_service_get_uid (CAMEL_SERVICE (store));
+	account = e_get_account_by_uid (uid);
 
 	if (account != NULL) {
-		gchar *tmp = folder_name;
+		gchar *text;
 
-		folder_name = g_strdup_printf (
+		text = g_strdup_printf (
 			"%s/%s", e_account_get_string (
 			account, E_ACCOUNT_NAME), _(folder_name));
-		gtk_label_set_text (label, folder_name);
-		g_free (tmp);
+		gtk_label_set_text (label, text);
+		g_free (text);
 	} else
 		gtk_label_set_text (label, _(folder_name));
 
+	g_object_unref (store);
 	g_free (folder_name);
 }
 
@@ -119,22 +135,28 @@ folder_selection_button_set_property (GObject *object,
                                       GParamSpec *pspec)
 {
 	switch (property_id) {
+		case PROP_ACCOUNT:
+			em_folder_selection_button_set_account (
+				EM_FOLDER_SELECTION_BUTTON (object),
+				g_value_get_object (value));
+			return;
+
+		case PROP_BACKEND:
+			em_folder_selection_button_set_backend (
+				EM_FOLDER_SELECTION_BUTTON (object),
+				g_value_get_object (value));
+			return;
+
 		case PROP_CAPTION:
 			em_folder_selection_button_set_caption (
 				EM_FOLDER_SELECTION_BUTTON (object),
 				g_value_get_string (value));
 			return;
 
-		case PROP_MULTISELECT:
-			em_folder_selection_button_set_multiselect (
+		case PROP_FOLDER_URI:
+			em_folder_selection_button_set_folder_uri (
 				EM_FOLDER_SELECTION_BUTTON (object),
-				g_value_get_boolean (value));
-			return;
-
-		case PROP_SESSION:
-			em_folder_selection_button_set_session (
-				EM_FOLDER_SELECTION_BUTTON (object),
-				g_value_get_object (value));
+				g_value_get_string (value));
 			return;
 
 		case PROP_TITLE:
@@ -154,6 +176,20 @@ folder_selection_button_get_property (GObject *object,
                                       GParamSpec *pspec)
 {
 	switch (property_id) {
+		case PROP_ACCOUNT:
+			g_value_set_object (
+				value,
+				em_folder_selection_button_get_account (
+				EM_FOLDER_SELECTION_BUTTON (object)));
+			return;
+
+		case PROP_BACKEND:
+			g_value_set_object (
+				value,
+				em_folder_selection_button_get_backend (
+				EM_FOLDER_SELECTION_BUTTON (object)));
+			return;
+
 		case PROP_CAPTION:
 			g_value_set_string (
 				value,
@@ -161,17 +197,10 @@ folder_selection_button_get_property (GObject *object,
 				EM_FOLDER_SELECTION_BUTTON (object)));
 			return;
 
-		case PROP_MULTISELECT:
-			g_value_set_boolean (
+		case PROP_FOLDER_URI:
+			g_value_set_string (
 				value,
-				em_folder_selection_button_get_multiselect (
-				EM_FOLDER_SELECTION_BUTTON (object)));
-			return;
-
-		case PROP_SESSION:
-			g_value_set_object (
-				value,
-				em_folder_selection_button_get_session (
+				em_folder_selection_button_get_folder_uri (
 				EM_FOLDER_SELECTION_BUTTON (object)));
 			return;
 
@@ -191,15 +220,21 @@ folder_selection_button_dispose (GObject *object)
 {
 	EMFolderSelectionButtonPrivate *priv;
 
-	priv = EM_FOLDER_SELECTION_BUTTON (object)->priv;
+	priv = EM_FOLDER_SELECTION_BUTTON_GET_PRIVATE (object);
 
-	if (priv->session != NULL) {
-		g_object_unref (priv->session);
-		priv->session = NULL;
+	if (priv->account != NULL) {
+		g_object_unref (priv->account);
+		priv->account = NULL;
+	}
+
+	if (priv->backend != NULL) {
+		g_object_unref (priv->backend);
+		priv->backend = NULL;
 	}
 
 	/* Chain up to parent's dispose() method. */
-	G_OBJECT_CLASS (em_folder_selection_button_parent_class)->dispose (object);
+	G_OBJECT_CLASS (em_folder_selection_button_parent_class)->
+		dispose (object);
 }
 
 static void
@@ -207,27 +242,26 @@ folder_selection_button_finalize (GObject *object)
 {
 	EMFolderSelectionButtonPrivate *priv;
 
-	priv = EM_FOLDER_SELECTION_BUTTON (object)->priv;
-
-	g_list_foreach (priv->uris, (GFunc) g_free, NULL);
-	g_list_free (priv->uris);
+	priv = EM_FOLDER_SELECTION_BUTTON_GET_PRIVATE (object);
 
 	g_free (priv->title);
 	g_free (priv->caption);
-	g_free (priv->uri);
+	g_free (priv->folder_uri);
 
 	/* Chain up to parent's finalize() method. */
-	G_OBJECT_CLASS (em_folder_selection_button_parent_class)->finalize (object);
+	G_OBJECT_CLASS (em_folder_selection_button_parent_class)->
+		finalize (object);
 }
 
 static void
 folder_selection_button_clicked (GtkButton *button)
 {
 	EMFolderSelectionButtonPrivate *priv;
-	EMFolderTree *emft;
+	EMFolderSelector *selector;
+	EMFolderTree *folder_tree;
+	EMFolderTreeModel *model = NULL;
 	GtkWidget *dialog;
 	GtkTreeSelection *selection;
-	GtkSelectionMode mode;
 	gpointer parent;
 
 	priv = EM_FOLDER_SELECTION_BUTTON (button)->priv;
@@ -235,53 +269,58 @@ folder_selection_button_clicked (GtkButton *button)
 	parent = gtk_widget_get_toplevel (GTK_WIDGET (button));
 	parent = gtk_widget_is_toplevel (parent) ? parent : NULL;
 
-	emft = (EMFolderTree *) em_folder_tree_new (priv->session);
-	emu_restore_folder_tree_state (emft);
+	if (priv->account != NULL && priv->account->source != NULL) {
+		EMailSession *session;
+		CamelService *service;
 
-	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (emft));
-	if (priv->multiple_select)
-		mode = GTK_SELECTION_MULTIPLE;
-	else
-		mode = GTK_SELECTION_SINGLE;
-	gtk_tree_selection_set_mode (selection, mode);
+		session = e_mail_backend_get_session (priv->backend);
 
-	em_folder_tree_set_excluded (
-		emft, EMFT_EXCLUDE_NOSELECT |
-		EMFT_EXCLUDE_VIRTUAL | EMFT_EXCLUDE_VTRASH);
+		service = camel_session_get_service (
+			CAMEL_SESSION (session), priv->account->uid);
 
-	dialog = em_folder_selector_new (
-		parent, emft, EM_FOLDER_SELECTOR_CAN_CREATE,
-		priv->title, priv->caption, NULL);
-
-	if (priv->multiple_select)
-		em_folder_selector_set_selected_list (
-			EM_FOLDER_SELECTOR (dialog), priv->uris);
-	else
-		em_folder_selector_set_selected (
-			EM_FOLDER_SELECTOR (dialog), priv->uri);
-
-	if (gtk_dialog_run (GTK_DIALOG (dialog)) != GTK_RESPONSE_OK)
-		goto exit;
-
-	if (priv->multiple_select) {
-		GList *uris;
-
-		uris = em_folder_selector_get_selected_uris (
-			EM_FOLDER_SELECTOR (dialog));
-		em_folder_selection_button_set_selection_mult (
-			EM_FOLDER_SELECTION_BUTTON (button), uris);
-	} else {
-		const gchar *uri;
-
-		uri = em_folder_selector_get_selected_uri (
-			EM_FOLDER_SELECTOR (dialog));
-		em_folder_selection_button_set_selection (
-			EM_FOLDER_SELECTION_BUTTON (button), uri);
+		if (CAMEL_IS_STORE (service)) {
+			model = em_folder_tree_model_new ();
+			em_folder_tree_model_set_session (model, session);
+			em_folder_tree_model_add_store (
+				model, CAMEL_STORE (service),
+				priv->account->name);
+		}
 	}
 
-	g_signal_emit (button, signals[SELECTED], 0);
+	if (model == NULL)
+		model = g_object_ref (em_folder_tree_model_get_default ());
+
+	dialog = em_folder_selector_new (
+		parent, priv->backend, model,
+		EM_FOLDER_SELECTOR_CAN_CREATE,
+		priv->title, priv->caption, NULL);
+
+	g_object_unref (model);
+
+	selector = EM_FOLDER_SELECTOR (dialog);
+	folder_tree = em_folder_selector_get_folder_tree (selector);
+
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (folder_tree));
+	gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
+
+	em_folder_tree_set_excluded (
+		folder_tree,
+		EMFT_EXCLUDE_NOSELECT |
+		EMFT_EXCLUDE_VIRTUAL |
+		EMFT_EXCLUDE_VTRASH);
+
+	em_folder_tree_set_selected (folder_tree, priv->folder_uri, FALSE);
+
+	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK) {
+		const gchar *uri;
+
+		uri = em_folder_selector_get_selected_uri (selector);
+		em_folder_selection_button_set_folder_uri (
+			EM_FOLDER_SELECTION_BUTTON (button), uri);
+
+		g_signal_emit (button, signals[SELECTED], 0);
+	}
 
-exit:
 	gtk_widget_destroy (dialog);
 }
 
@@ -302,6 +341,27 @@ em_folder_selection_button_class_init (EMFolderSelectionButtonClass *class)
 	button_class = GTK_BUTTON_CLASS (class);
 	button_class->clicked = folder_selection_button_clicked;
 
+	g_object_class_install_property (
+		object_class,
+		PROP_ACCOUNT,
+		g_param_spec_object (
+			"account",
+			NULL,
+			NULL,
+			E_TYPE_ACCOUNT,
+			G_PARAM_READWRITE));
+
+	g_object_class_install_property (
+		object_class,
+		PROP_BACKEND,
+		g_param_spec_object (
+			"backend",
+			NULL,
+			NULL,
+			E_TYPE_MAIL_BACKEND,
+			G_PARAM_READWRITE |
+			G_PARAM_CONSTRUCT));
+
 	g_object_class_install_property (
 		object_class,
 		PROP_CAPTION,
@@ -315,23 +375,12 @@ em_folder_selection_button_class_init (EMFolderSelectionButtonClass *class)
 
 	g_object_class_install_property (
 		object_class,
-		PROP_MULTISELECT,
-		g_param_spec_boolean (
-			"multiselect",
+		PROP_FOLDER_URI,
+		g_param_spec_string (
+			"folder-uri",
 			NULL,
 			NULL,
-			FALSE,
-			G_PARAM_READWRITE |
-			G_PARAM_CONSTRUCT));
-
-	g_object_class_install_property (
-		object_class,
-		PROP_SESSION,
-		g_param_spec_object (
-			"session",
 			NULL,
-			NULL,
-			E_TYPE_MAIL_SESSION,
 			G_PARAM_READWRITE |
 			G_PARAM_CONSTRUCT));
 
@@ -361,43 +410,90 @@ em_folder_selection_button_init (EMFolderSelectionButton *emfsb)
 {
 	GtkWidget *box;
 
-	emfsb->priv = G_TYPE_INSTANCE_GET_PRIVATE (
-		emfsb, EM_TYPE_FOLDER_SELECTION_BUTTON,
-		EMFolderSelectionButtonPrivate);
-
-	emfsb->priv->multiple_select = FALSE;
+	emfsb->priv = EM_FOLDER_SELECTION_BUTTON_GET_PRIVATE (emfsb);
 
 	box = gtk_hbox_new (FALSE, 4);
+	gtk_container_add (GTK_CONTAINER (emfsb), box);
+	gtk_widget_show (box);
 
 	emfsb->priv->icon = gtk_image_new ();
-	gtk_widget_show (emfsb->priv->icon);
 	gtk_box_pack_start (GTK_BOX (box), emfsb->priv->icon, FALSE, TRUE, 0);
+	gtk_widget_show (emfsb->priv->icon);
 
 	emfsb->priv->label = gtk_label_new ("");
-	gtk_widget_show (emfsb->priv->label);
 	gtk_label_set_justify (GTK_LABEL (emfsb->priv->label), GTK_JUSTIFY_LEFT);
 	gtk_misc_set_alignment (GTK_MISC (emfsb->priv->label), 0.0, 0.5);
 	gtk_box_pack_start (GTK_BOX (box), emfsb->priv->label, TRUE, TRUE, 0);
-
-	gtk_widget_show (box);
-	gtk_container_add (GTK_CONTAINER (emfsb), box);
-
-	folder_selection_button_set_contents (emfsb);
+	gtk_widget_show (emfsb->priv->label);
 }
 
 GtkWidget *
-em_folder_selection_button_new (EMailSession *session,
+em_folder_selection_button_new (EMailBackend *backend,
                                 const gchar *title,
                                 const gchar *caption)
 {
-	g_return_val_if_fail (E_IS_MAIL_SESSION (session), NULL);
+	g_return_val_if_fail (E_IS_MAIL_BACKEND (backend), NULL);
 
 	return g_object_new (
 		EM_TYPE_FOLDER_SELECTION_BUTTON,
-		"session", session, "title", title,
+		"backend", backend, "title", title,
 		"caption", caption, NULL);
 }
 
+EAccount *
+em_folder_selection_button_get_account (EMFolderSelectionButton *button)
+{
+	g_return_val_if_fail (EM_IS_FOLDER_SELECTION_BUTTON (button), NULL);
+
+	return button->priv->account;
+}
+
+void
+em_folder_selection_button_set_account (EMFolderSelectionButton *button,
+                                        EAccount *account)
+{
+	g_return_if_fail (EM_IS_FOLDER_SELECTION_BUTTON (button));
+
+	if (account != NULL) {
+		g_return_if_fail (E_IS_ACCOUNT (account));
+		g_object_ref (account);
+	}
+
+	if (button->priv->account != NULL)
+		g_object_unref (button->priv->account);
+
+	button->priv->account = account;
+
+	g_object_notify (G_OBJECT (button), "account");
+}
+
+EMailBackend *
+em_folder_selection_button_get_backend (EMFolderSelectionButton *button)
+{
+	g_return_val_if_fail (EM_IS_FOLDER_SELECTION_BUTTON (button), NULL);
+
+	return button->priv->backend;
+}
+
+void
+em_folder_selection_button_set_backend (EMFolderSelectionButton *button,
+                                        EMailBackend *backend)
+{
+	g_return_if_fail (EM_IS_FOLDER_SELECTION_BUTTON (button));
+
+	if (backend != NULL) {
+		g_return_if_fail (E_IS_MAIL_BACKEND (backend));
+		g_object_ref (backend);
+	}
+
+	if (button->priv->backend != NULL)
+		g_object_unref (button->priv->backend);
+
+	button->priv->backend = backend;
+
+	g_object_notify (G_OBJECT (button), "backend");
+}
+
 const gchar *
 em_folder_selection_button_get_caption (EMFolderSelectionButton *button)
 {
@@ -418,123 +514,30 @@ em_folder_selection_button_set_caption (EMFolderSelectionButton *button,
 	g_object_notify (G_OBJECT (button), "caption");
 }
 
-gboolean
-em_folder_selection_button_get_multiselect (EMFolderSelectionButton *button)
-{
-	g_return_val_if_fail (EM_IS_FOLDER_SELECTION_BUTTON (button), FALSE);
-
-	return button->priv->multiple_select;
-}
-
-void
-em_folder_selection_button_set_multiselect (EMFolderSelectionButton *button,
-                                            gboolean multiselect)
-{
-	g_return_if_fail (EM_IS_FOLDER_SELECTION_BUTTON (button));
-
-	button->priv->multiple_select = multiselect;
-
-	g_object_notify (G_OBJECT (button), "multiselect");
-}
-
 const gchar *
-em_folder_selection_button_get_selection (EMFolderSelectionButton *button)
+em_folder_selection_button_get_folder_uri (EMFolderSelectionButton *button)
 {
 	g_return_val_if_fail (EM_IS_FOLDER_SELECTION_BUTTON (button), NULL);
 
-	return button->priv->uri;
+	return button->priv->folder_uri;
 }
 
 void
-em_folder_selection_button_set_selection (EMFolderSelectionButton *button,
-                                          const gchar *uri)
+em_folder_selection_button_set_folder_uri (EMFolderSelectionButton *button,
+                                           const gchar *folder_uri)
 {
 	g_return_if_fail (EM_IS_FOLDER_SELECTION_BUTTON (button));
 
-	if (g_strcmp0 (button->priv->uri, uri) == 0)
-		return;
+	/* An empty string is equivalent to NULL. */
+	if (folder_uri != NULL && *folder_uri == '\0')
+		folder_uri = NULL;
 
-	g_free (button->priv->uri);
-	button->priv->uri = g_strdup (uri);
+	g_free (button->priv->folder_uri);
+	button->priv->folder_uri = g_strdup (folder_uri);
 
 	folder_selection_button_set_contents (button);
-}
 
-GList *
-em_folder_selection_button_get_selection_mult (EMFolderSelectionButton *button)
-{
-	g_return_val_if_fail (EM_IS_FOLDER_SELECTION_BUTTON (button), NULL);
-
-	return button->priv->uris;
-}
-
-void
-em_folder_selection_button_set_selection_mult (EMFolderSelectionButton *button,
-                                               GList *uris)
-{
-	gchar *caption, *tmp, *tmp2;
-
-	g_return_if_fail (EM_IS_FOLDER_SELECTION_BUTTON (button));
-
-	g_list_foreach (button->priv->uris, (GFunc) g_free, NULL);
-	g_list_free (button->priv->uris);
-
-	button->priv->uris = uris;
-
-	/* compile the name */
-	caption = g_strdup ("");
-
-	while (uris) {
-		tmp = em_utils_folder_name_from_uri (uris->data);
-		if (tmp) {
-			tmp2 = g_strconcat (caption, ", ", tmp, NULL);
-			g_free (caption);
-			caption = tmp2;
-			g_free (tmp);
-			uris = uris->next;
-		} else {
-			/* apparently, we do not know this folder, so we'll just skip it */
-			g_free (uris->data);
-			uris = g_list_next (uris);
-			button->priv->uris = g_list_remove (
-				button->priv->uris, uris->data);
-		}
-	}
-
-	if (caption[0])
-		gtk_label_set_text (
-			GTK_LABEL (button->priv->label), caption + 2);
-	else
-		folder_selection_button_unselected (button);
-
-	g_free (caption);
-}
-
-EMailSession *
-em_folder_selection_button_get_session (EMFolderSelectionButton *button)
-{
-	g_return_val_if_fail (EM_IS_FOLDER_SELECTION_BUTTON (button), NULL);
-
-	return button->priv->session;
-}
-
-void
-em_folder_selection_button_set_session (EMFolderSelectionButton *button,
-                                        EMailSession *session)
-{
-	g_return_if_fail (EM_IS_FOLDER_SELECTION_BUTTON (button));
-
-	if (session != NULL) {
-		g_return_if_fail (E_IS_MAIL_SESSION (session));
-		g_object_ref (session);
-	}
-
-	if (button->priv->session != NULL)
-		g_object_unref (button->priv->session);
-
-	button->priv->session = session;
-
-	g_object_notify (G_OBJECT (button), "session");
+	g_object_notify (G_OBJECT (button), "folder-uri");
 }
 
 const gchar *
