@@ -19,6 +19,10 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "e-util/e-alert-dialog.h"
 #include "e-task-shell-view-private.h"
 
@@ -140,7 +144,7 @@ action_task_list_copy_cb (GtkAction *action,
 
 	copy_source_dialog (
 		GTK_WINDOW (shell_window),
-		source, E_CAL_SOURCE_TYPE_TODO);
+		source, E_CAL_CLIENT_SOURCE_TYPE_TASKS);
 }
 
 static void
@@ -153,7 +157,7 @@ action_task_list_delete_cb (GtkAction *action,
 	EShellWindow *shell_window;
 	EShellView *shell_view;
 	ETaskTable *task_table;
-	ECal *client;
+	ECalClient *client;
 	ECalModel *model;
 	ESourceSelector *selector;
 	ESourceGroup *source_group;
@@ -189,13 +193,18 @@ action_task_list_delete_cb (GtkAction *action,
 	uri = e_source_get_uri (source);
 	client = e_cal_model_get_client_for_uri (model, uri);
 	if (client == NULL)
-		client = e_cal_new_from_uri (uri, E_CAL_SOURCE_TYPE_JOURNAL);
+		client = e_cal_client_new_from_uri (
+			uri, E_CAL_CLIENT_SOURCE_TYPE_MEMOS, NULL);
 	g_free (uri);
 
 	g_return_if_fail (client != NULL);
 
-	if (!e_cal_remove (client, &error)) {
-		g_warning ("%s", error->message);
+	e_client_remove_sync (E_CLIENT (client), NULL, &error);
+
+	if (error != NULL) {
+		g_warning (
+			"%s: Failed to remove client: %s",
+			G_STRFUNC, error->message);
 		g_error_free (error);
 		return;
 	}
@@ -209,8 +218,12 @@ action_task_list_delete_cb (GtkAction *action,
 	source_group = e_source_peek_group (source);
 	e_source_group_remove_source (source_group, source);
 
-	if (!e_source_list_sync (source_list, &error)) {
-		g_warning ("%s", error->message);
+	e_source_list_sync (source_list, &error);
+
+	if (error != NULL) {
+		g_warning (
+			"%s: Failed to sync srouce list: %s",
+			G_STRFUNC, error->message);
 		g_error_free (error);
 	}
 }
@@ -285,7 +298,7 @@ action_task_list_refresh_cb (GtkAction *action,
 	ETaskShellContent *task_shell_content;
 	ETaskShellSidebar *task_shell_sidebar;
 	ESourceSelector *selector;
-	ECal *client;
+	ECalClient *client;
 	ECalModel *model;
 	ESource *source;
 	gchar *uri;
@@ -307,11 +320,13 @@ action_task_list_refresh_cb (GtkAction *action,
 	if (client == NULL)
 		return;
 
-	g_return_if_fail (e_cal_get_refresh_supported (client));
+	g_return_if_fail (e_client_check_refresh_supported (E_CLIENT (client)));
 
-	if (!e_cal_refresh (client, &error) && error) {
+	e_client_refresh_sync (E_CLIENT (client), NULL, &error);
+
+	if (error != NULL) {
 		g_warning (
-			"%s: Failed to refresh '%s', %s\n",
+			"%s: Failed to refresh '%s', %s",
 			G_STRFUNC, e_source_peek_name (source),
 			error->message);
 		g_error_free (error);
@@ -403,7 +418,7 @@ action_task_new_cb (GtkAction *action,
 	EShellWindow *shell_window;
 	ETaskShellContent *task_shell_content;
 	ETaskTable *task_table;
-	ECal *client;
+	ECalClient *client;
 	ECalComponent *comp;
 	CompEditor *editor;
 	GSList *list;
@@ -631,7 +646,7 @@ action_task_save_as_cb (GtkAction *action,
 		return;
 
 	/* XXX We only save the first selected task. */
-	string = e_cal_get_component_as_string (
+	string = e_cal_client_get_component_as_string (
 		comp_data->client, comp_data->icalcomp);
 	if (string == NULL) {
 		g_warning ("Could not convert task to a string");
