@@ -19,6 +19,10 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "e-mail-shell-sidebar.h"
 
 #include "mail/e-mail-backend.h"
@@ -116,8 +120,6 @@ mail_shell_sidebar_constructed (GObject *object)
 	EShellWindow *shell_window;
 	EShellView *shell_view;
 	EShell *shell;
-	EMailBackend *backend;
-	EMailSession *session;
 	GtkTreeSelection *selection;
 	GtkTreeView *tree_view;
 	GtkWidget *container;
@@ -134,9 +136,6 @@ mail_shell_sidebar_constructed (GObject *object)
 	shell = e_shell_window_get_shell (shell_window);
 	shell_settings = e_shell_get_shell_settings (shell);
 
-	backend = E_MAIL_BACKEND (shell_backend);
-	session = e_mail_backend_get_session (backend);
-
 	mail_shell_sidebar = E_MAIL_SHELL_SIDEBAR (object);
 
 	/* Build sidebar widgets. */
@@ -154,7 +153,9 @@ mail_shell_sidebar_constructed (GObject *object)
 
 	container = widget;
 
-	widget = e_mail_sidebar_new (session);
+	widget = e_mail_sidebar_new (
+		E_MAIL_BACKEND (shell_backend),
+		E_ALERT_SINK (shell_sidebar));
 	gtk_container_add (GTK_CONTAINER (container), widget);
 	mail_shell_sidebar->priv->folder_tree = g_object_ref (widget);
 	gtk_widget_show (widget);
