@@ -32,7 +32,7 @@
 #include <libxml/xpath.h>
 #include <libxml/xpathInternals.h>
 
-#include <libecal/e-cal.h>
+#include <libecal/e-cal-client.h>
 #include <libedataserver/e-proxy.h>
 #include <libedataserverui/e-cell-renderer-color.h>
 #include <libedataserverui/e-passwords.h>
@@ -891,7 +891,7 @@ soup_authenticate (SoupSession *session, SoupMessage *msg, SoupAuth *auth, gbool
 		return;
 
 	if (!retrying && !password)
-		password = e_passwords_get_password ("Calendar", g_object_get_data (dialog, "caldav-auth-key"));
+		password = e_passwords_get_password (NULL, g_object_get_data (dialog, "caldav-auth-key"));
 
 	if (!password || !*password || retrying) {
 		gchar *pass, *prompt, *add = NULL;
@@ -918,7 +918,7 @@ soup_authenticate (SoupSession *session, SoupMessage *msg, SoupAuth *auth, gbool
 		}
 
 		pass = e_passwords_ask_password (_("Enter password"),
-			"Calendar", g_object_get_data (dialog, "caldav-auth-key"), prompt,
+			NULL, g_object_get_data (dialog, "caldav-auth-key"), prompt,
 			E_PASSWORDS_REMEMBER_NEVER | E_PASSWORDS_DISABLE_REMEMBER | E_PASSWORDS_SECRET,
 			NULL, GTK_WINDOW (dialog));
 
@@ -1331,7 +1331,7 @@ init_dialog (GtkDialog *dialog, GtkWidget **new_url_entry, GtkWidget **new_userm
 	hbox = gtk_hbox_new (FALSE, 2);
 	gtk_box_pack_start (content_area, hbox, FALSE, FALSE, 0);
 
-	label = gtk_label_new_with_mnemonic (_("User e-_mail:"));
+	label = gtk_label_new_with_mnemonic (_("User e_mail:"));
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), *new_usermail_combo);
 
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 2);
@@ -1369,13 +1369,13 @@ init_dialog (GtkDialog *dialog, GtkWidget **new_url_entry, GtkWidget **new_userm
 
 	switch (source_type) {
 	default:
-	case E_CAL_SOURCE_TYPE_EVENT:
+	case E_CAL_CLIENT_SOURCE_TYPE_EVENTS:
 		source_type_str = "VEVENT";
 		break;
-	case E_CAL_SOURCE_TYPE_TODO:
+	case E_CAL_CLIENT_SOURCE_TYPE_TASKS:
 		source_type_str = "VTODO";
 		break;
-	case E_CAL_SOURCE_TYPE_JOURNAL:
+	case E_CAL_CLIENT_SOURCE_TYPE_MEMOS:
 		source_type_str = "VJOURNAL";
 		break;
 	}
