@@ -44,13 +44,14 @@
 #include <e-util/e-plugin.h>
 
 #include <libebook/e-contact.h>
-#include <libebook/e-book.h>
+#include <libebook/e-book-client.h>
 
-#include <libecal/e-cal.h>
+#include <libecal/e-cal-client.h>
 #include <libecal/e-cal-component.h>
 
 #include <libedataserver/e-data-server-util.h>
-#include <libedataserverui/e-source-selector-dialog.h>
+#include <libedataserverui/e-source-combo-box.h>
+#include <libedataserverui/e-client-utils.h>
 
 #include <mail/e-mail-backend.h>
 #include <mail/e-mail-local.h>
@@ -59,6 +60,9 @@
 #include <mail/mail-tools.h>
 #include <mail/em-utils.h>
 #include <shell/e-shell.h>
+#include <shell/e-shell-window.h>
+#include <shell/e-shell-view.h>
+#include <shell/e-shell-sidebar.h>
 
 #include <libpst/libpst.h>
 #include <libpst/timeconv.h>
@@ -76,7 +80,7 @@ gint pst_init (pst_file *pst, gchar *filename);
 gchar *get_pst_rootname (pst_file *pst, gchar *filename);
 static void pst_error_msg (const gchar *fmt, ...);
 static void pst_import_folders (PstImporter *m, pst_desc_tree *topitem);
-static void pst_process_item (PstImporter *m, pst_desc_tree *d_ptr);
+static void pst_process_item (PstImporter *m, pst_desc_tree *d_ptr, gchar **previouss_folder);
 static void pst_process_folder (PstImporter *m, pst_item *item);
 static void pst_process_email (PstImporter *m, pst_item *item);
 static void pst_process_contact (PstImporter *m, pst_item *item);
@@ -88,6 +92,7 @@ static void pst_import_file (PstImporter *m);
 gchar *foldername_to_utf8 (const gchar *pstname);
 gchar *string_to_utf8 (const gchar *string);
 void contact_set_date (EContact *contact, EContactField id, FILETIME *date);
+static void fill_calcomponent (PstImporter *m, pst_item *item, ECalComponent *ec, const gchar *type);
 struct icaltimetype get_ical_date (FILETIME *date, gboolean is_date);
 gchar *rfc2445_datetime_format (FILETIME *ft);
 
@@ -110,6 +115,7 @@ struct _PstImporter {
 	EImport *import;
 	EImportTarget *target;
 
+	gint waiting_open;
 	GMutex *status_lock;
 	gchar *status_what;
 	gint status_pc;
@@ -119,16 +125,19 @@ struct _PstImporter {
 	pst_file pst;
 
 	CamelFolder *folder;
-	gchar *parent_uri;
 	gchar *folder_name;
 	gchar *folder_uri;
 	gint folder_count;
 	gint current_item;
 
-	EBook *addressbook;
-	ECal *calendar;
-	ECal *tasks;
-	ECal *journal;
+	EBookClient *addressbook;
+	ECalClient *calendar;
+	ECalClient *tasks;
+	ECalClient *journal;
+
+	/* progress indicator */
+	gint position;
+	gint total;
 };
 
 gboolean
@@ -201,7 +210,7 @@ static void
 folder_selected (EMFolderSelectionButton *button, EImportTargetURI *target)
 {
 	g_free (target->uri_dest);
-	target->uri_dest = g_strdup (em_folder_selection_button_get_selection (button));
+	target->uri_dest = g_strdup (em_folder_selection_button_get_folder_uri (button));
 }
 
 /**
@@ -213,6 +222,7 @@ get_suggested_foldername (EImportTargetURI *target)
 	EShell *shell;
 	EShellBackend *shell_backend;
 	EMailSession *session;
+	GtkWindow *window;
 	const gchar *inbox;
 	gchar *delim, *filename;
 	gchar *rootname = NULL;
@@ -226,18 +236,58 @@ get_suggested_foldername (EImportTargetURI *target)
 	shell_backend = e_shell_get_backend_by_name (shell, "mail");
 	session = e_mail_backend_get_session (E_MAIL_BACKEND (shell_backend));
 
-	/* Suggest a folder that is in the same mail storage as the users' inbox,
-	   with a name derived from the .PST file */
-	inbox = e_mail_local_get_folder_uri (E_MAIL_LOCAL_FOLDER_INBOX);
+	foldername = NULL;
 
-	delim = g_strrstr (inbox, "#");
-	if (delim != NULL) {
-		foldername = g_string_new_len (inbox, delim-inbox);
-	} else {
-		foldername = g_string_new (inbox);
+	/* preselect the folder selected in a mail view */
+	window = e_shell_get_active_window (shell);
+	if (E_IS_SHELL_WINDOW (window)) {
+		EShellWindow *shell_window;
+		const gchar *view;
+
+		shell_window = E_SHELL_WINDOW (window);
+		view = e_shell_window_get_active_view (shell_window);
+
+		if (view && g_str_equal (view, "mail")) {
+			EShellView *shell_view;
+			EShellSidebar *shell_sidebar;
+			EMFolderTree *folder_tree = NULL;
+			gchar *selected_uri;
+
+			shell_view = e_shell_window_get_shell_view (
+				shell_window, view);
+
+			shell_sidebar =
+				e_shell_view_get_shell_sidebar (shell_view);
+
+			g_object_get (
+				shell_sidebar, "folder-tree",
+				&folder_tree, NULL);
+
+			selected_uri = em_folder_tree_get_selected_uri (folder_tree);
+
+			g_object_unref (folder_tree);
+
+			if (selected_uri && *selected_uri)
+				foldername = g_string_new (selected_uri);
+
+			g_free (selected_uri);
+		}
 	}
 
-	g_string_append_c (foldername, '#');
+	if (!foldername) {
+		/* Suggest a folder that is in the same mail storage as the users' inbox,
+		   with a name derived from the .PST file */
+		inbox = e_mail_local_get_folder_uri (E_MAIL_LOCAL_FOLDER_INBOX);
+
+		delim = g_strrstr (inbox, "#");
+		if (delim != NULL) {
+			foldername = g_string_new_len (inbox, delim-inbox);
+		} else {
+			foldername = g_string_new (inbox);
+		}
+	}
+
+	g_string_append_c (foldername, '/');
 
 	filename = g_filename_from_uri (target->uri_src, NULL, NULL);
 
@@ -279,7 +329,7 @@ get_suggested_foldername (EImportTargetURI *target)
 		}
 
 		if (folder != NULL) {
-			pst_error_msg ("Error searching for an unused folder name. uri=%s", foldername);
+			pst_error_msg ("Error searching for an unused folder name. uri=%s", foldername->str);
 		}
 	}
 
@@ -287,28 +337,106 @@ get_suggested_foldername (EImportTargetURI *target)
 
 }
 
+static void
+widget_sanitizer_cb (GtkToggleButton *button, GtkWidget *source_combo)
+{
+	g_return_if_fail (button != NULL);
+	g_return_if_fail (source_combo != NULL);
+
+	gtk_widget_set_sensitive (source_combo, gtk_toggle_button_get_active (button));
+}
+
+static const gchar *
+get_source_combo_key (EClientSourceType source_type)
+{
+	const gchar *key = NULL;
+
+	switch (source_type) {
+	case E_CLIENT_SOURCE_TYPE_CONTACTS:
+		key = "pst-contacts-source-combo";
+		break;
+	case E_CLIENT_SOURCE_TYPE_EVENTS:
+		key = "pst-events-source-combo";
+		break;
+	case E_CLIENT_SOURCE_TYPE_TASKS:
+		key = "pst-tasks-source-combo";
+		break;
+	case E_CLIENT_SOURCE_TYPE_MEMOS:
+		key = "pst-memos-source-combo";
+		break;
+	case E_CLIENT_SOURCE_TYPE_LAST:
+		break;
+	}
+
+	return key;
+}
+
+static void
+add_source_list_with_check (GtkWidget *frame, const gchar *caption, EClientSourceType source_type, GCallback toggle_callback, EImportTarget *target)
+{
+	GtkWidget *check, *hbox;
+	ESourceList *source_list = NULL;
+	GtkWidget *combo = NULL;
+
+	g_return_if_fail (frame != NULL);
+	g_return_if_fail (caption != NULL);
+	g_return_if_fail (toggle_callback != NULL);
+
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
+
+	check = gtk_check_button_new_with_mnemonic (caption);
+	gtk_toggle_button_set_active ((GtkToggleButton *) check, FALSE);
+	g_signal_connect (check, "toggled", toggle_callback, target);
+	gtk_box_pack_start ((GtkBox *) hbox, check, FALSE, FALSE, 0);
+
+	if (e_client_utils_get_sources (&source_list, source_type, NULL)) {
+		ESource *source;
+
+		combo = e_source_combo_box_new (source_list);
+		source = e_source_list_peek_default_source (source_list);
+		if (!source)
+			source = e_source_list_peek_source_any (source_list);
+		e_source_combo_box_set_active (E_SOURCE_COMBO_BOX (combo), source);
+
+		gtk_box_pack_end ((GtkBox *) hbox, combo, FALSE, FALSE, 0);
+
+		g_signal_connect (check, "toggled", G_CALLBACK (widget_sanitizer_cb), combo);
+		widget_sanitizer_cb (GTK_TOGGLE_BUTTON (check), combo);
+	}
+
+	gtk_box_pack_start ((GtkBox *) frame, hbox, FALSE, FALSE, 0);
+
+	if (combo) {
+		const gchar *key = get_source_combo_key (source_type);
+
+		g_return_if_fail (key != NULL);
+
+		g_datalist_set_data (&target->data, key, combo);
+	}
+}
+
 GtkWidget *
 org_credativ_evolution_readpst_getwidget (EImport *ei, EImportTarget *target, EImportImporter *im)
 {
 	EShell *shell;
 	EShellBackend *shell_backend;
-	GtkWidget *hbox, *framebox, *w;
+	GtkWidget *hbox, *framebox, *w, *check;
 	gchar *foldername;
 
 	g_datalist_set_data (&target->data, "pst-do-mail", GINT_TO_POINTER (TRUE));
-	g_datalist_set_data (&target->data, "pst-do-addr", GINT_TO_POINTER (TRUE));
-	g_datalist_set_data (&target->data, "pst-do-appt", GINT_TO_POINTER (TRUE));
-	g_datalist_set_data (&target->data, "pst-do-task", GINT_TO_POINTER (TRUE));
-	g_datalist_set_data (&target->data, "pst-do-journal", GINT_TO_POINTER (TRUE));
+	g_datalist_set_data (&target->data, "pst-do-addr", GINT_TO_POINTER (FALSE));
+	g_datalist_set_data (&target->data, "pst-do-appt", GINT_TO_POINTER (FALSE));
+	g_datalist_set_data (&target->data, "pst-do-task", GINT_TO_POINTER (FALSE));
+	g_datalist_set_data (&target->data, "pst-do-journal", GINT_TO_POINTER (FALSE));
 
 	framebox = gtk_vbox_new (FALSE, 2);
 
 	/* Mail */
 	hbox = gtk_hbox_new (FALSE, 0);
-	w = gtk_check_button_new_with_mnemonic (_("_Mail"));
-	gtk_toggle_button_set_active ((GtkToggleButton *) w, TRUE);
-	g_signal_connect (w, "toggled", G_CALLBACK (checkbox_mail_toggle_cb), target);
-	gtk_box_pack_start ((GtkBox *) hbox, w, FALSE, FALSE, 0);
+	check = gtk_check_button_new_with_mnemonic (_("_Mail"));
+	gtk_toggle_button_set_active ((GtkToggleButton *) check, TRUE);
+	g_signal_connect (check, "toggled", G_CALLBACK (checkbox_mail_toggle_cb), target);
+	gtk_box_pack_start ((GtkBox *) hbox, check, FALSE, FALSE, 0);
 
 	shell = e_shell_get_default ();
 	shell_backend = e_shell_get_backend_by_name (shell, "mail");
@@ -319,39 +447,21 @@ org_credativ_evolution_readpst_getwidget (EImport *ei, EImportTarget *target, EI
 		_("Select folder to import into"));
 	foldername = get_suggested_foldername ((EImportTargetURI *) target);
 	((EImportTargetURI *) target)->uri_dest = g_strdup (foldername);
-	em_folder_selection_button_set_selection ((EMFolderSelectionButton *) w, foldername);
+	em_folder_selection_button_set_folder_uri ((EMFolderSelectionButton *) w, foldername);
 	g_signal_connect (w, "selected", G_CALLBACK (folder_selected), target);
 	gtk_box_pack_end ((GtkBox *) hbox, w, FALSE, FALSE, 0);
+	g_signal_connect (check, "toggled", G_CALLBACK (widget_sanitizer_cb), w);
 
 	w = gtk_label_new (_("Destination folder:"));
 	gtk_box_pack_end ((GtkBox *) hbox, w, FALSE, TRUE, 6);
+	g_signal_connect (check, "toggled", G_CALLBACK (widget_sanitizer_cb), w);
 
 	gtk_box_pack_start ((GtkBox *) framebox, hbox, FALSE, FALSE, 0);
 
-	/* Address book */
-	w = gtk_check_button_new_with_mnemonic (_("_Address Book"));
-	gtk_toggle_button_set_active ((GtkToggleButton *) w, FALSE);
-	/*gtk_widget_set_sensitive ((GtkWidget *)w, FALSE);*/ /* Disable until implemented */
-	g_signal_connect (w, "toggled", G_CALLBACK (checkbox_addr_toggle_cb), target);
-	gtk_box_pack_start ((GtkBox *) framebox, w, FALSE, FALSE, 0);
-
-	/* Appointments */
-	w = gtk_check_button_new_with_mnemonic (_("A_ppointments"));
-	gtk_toggle_button_set_active ((GtkToggleButton *) w, FALSE);
-	g_signal_connect (w, "toggled", G_CALLBACK (checkbox_appt_toggle_cb), target);
-	gtk_box_pack_start ((GtkBox *) framebox, w, FALSE, FALSE, 0);
-
-	/* Tasks */
-	w = gtk_check_button_new_with_mnemonic (_("_Tasks"));
-	gtk_toggle_button_set_active ((GtkToggleButton *) w, FALSE);
-	g_signal_connect (w, "toggled", G_CALLBACK (checkbox_task_toggle_cb), target);
-	gtk_box_pack_start ((GtkBox *) framebox, w, FALSE, FALSE, 0);
-
-	/* Journal */
-	w = gtk_check_button_new_with_mnemonic (_("_Journal entries"));
-	gtk_toggle_button_set_active ((GtkToggleButton *) w, FALSE);
-	g_signal_connect (w, "toggled", G_CALLBACK (checkbox_journal_toggle_cb), target);
-	gtk_box_pack_start ((GtkBox *) framebox, w, FALSE, FALSE, 0);
+	add_source_list_with_check (framebox, _("_Address Book"), E_CLIENT_SOURCE_TYPE_CONTACTS, G_CALLBACK (checkbox_addr_toggle_cb), target);
+	add_source_list_with_check (framebox, _("A_ppointments"), E_CLIENT_SOURCE_TYPE_EVENTS, G_CALLBACK (checkbox_appt_toggle_cb), target);
+	add_source_list_with_check (framebox, _("_Tasks"), E_CLIENT_SOURCE_TYPE_TASKS, G_CALLBACK (checkbox_task_toggle_cb), target);
+	add_source_list_with_check (framebox, _("_Journal entries"), E_CLIENT_SOURCE_TYPE_MEMOS, G_CALLBACK (checkbox_journal_toggle_cb), target);
 
 	gtk_widget_show_all (framebox);
 
@@ -360,98 +470,139 @@ org_credativ_evolution_readpst_getwidget (EImport *ei, EImportTarget *target, EI
 	return framebox;
 }
 
+static void
+client_opened_cb (GObject *source_object, GAsyncResult *result, gpointer user_data)
+{
+	PstImporter *m = user_data;
+	GError *error = NULL;
+	EClient *client = NULL;
+
+	g_return_if_fail (result != NULL);
+	g_return_if_fail (m != NULL);
+	g_return_if_fail (m->waiting_open > 0);
+
+	if (!e_client_utils_open_new_finish (E_SOURCE (source_object), result, &client, &error))
+		client = NULL;
+
+	if (error)
+		g_debug ("%s: Failed to open client: %s", G_STRFUNC, error->message);
+	g_clear_error (&error);
+
+	if (client) {
+		if (E_IS_BOOK_CLIENT (client)) {
+			m->addressbook = E_BOOK_CLIENT (client);
+		} else if (E_IS_CAL_CLIENT (client)) {
+			ECalClient *cal_client = E_CAL_CLIENT (client);
+			switch (e_cal_client_get_source_type (cal_client)) {
+			case E_CAL_CLIENT_SOURCE_TYPE_EVENTS:
+				m->calendar = cal_client;
+				break;
+			case E_CAL_CLIENT_SOURCE_TYPE_TASKS:
+				m->tasks = cal_client;
+				break;
+			case E_CAL_CLIENT_SOURCE_TYPE_MEMOS:
+				m->journal = cal_client;
+				break;
+			default:
+				g_object_unref (client);
+				g_warn_if_reached ();
+				break;
+			}
+		} else {
+			g_object_unref (client);
+			g_warn_if_reached ();
+		}
+	}
+
+	m->waiting_open--;
+	if (!m->waiting_open)
+		mail_msg_unordered_push (m);
+}
+
+static void
+open_client (PstImporter *m, EClientSourceType source_type)
+{
+	ESourceComboBox *combo;
+	ESource *source;
+
+	combo = g_datalist_get_data (&m->target->data, get_source_combo_key (source_type));
+	g_return_if_fail (combo != NULL);
+
+	source = e_source_combo_box_get_active (combo);
+	g_return_if_fail (source != NULL);
+
+	m->waiting_open++;
+
+	e_client_utils_open_new (source, source_type, FALSE, m->cancellable,
+		e_client_utils_authenticate_handler, NULL,
+		client_opened_cb, m);
+}
+
+static void
+pst_prepare_run (PstImporter *m)
+{
+	if (GPOINTER_TO_INT (g_datalist_get_data (&m->target->data, "pst-do-addr"))) {
+		open_client (m, E_CLIENT_SOURCE_TYPE_CONTACTS);
+	}
+
+	if (GPOINTER_TO_INT (g_datalist_get_data (&m->target->data, "pst-do-appt"))) {
+		open_client (m, E_CLIENT_SOURCE_TYPE_EVENTS);
+	}
+
+	if (GPOINTER_TO_INT (g_datalist_get_data (&m->target->data, "pst-do-task"))) {
+		open_client (m, E_CLIENT_SOURCE_TYPE_TASKS);
+	}
+
+	if (GPOINTER_TO_INT (g_datalist_get_data (&m->target->data, "pst-do-journal"))) {
+		open_client (m, E_CLIENT_SOURCE_TYPE_MEMOS);
+	}
+
+	if (!m->waiting_open)
+		mail_msg_unordered_push (m);
+}
+
 static gchar *
 pst_import_describe (PstImporter *m, gint complete)
 {
 	return g_strdup (_("Importing Outlook data"));
 }
 
-static ECal*
-open_ecal (ECalSourceType type, const gchar *name)
-{
-	/* Hack - grab the first calendar we can find
-		TODO - add a selection mechanism in get_widget */
-	ESource *primary;
-	ESourceList *source_list;
-	ECal *cal;
-
-	if ((e_cal_get_sources (&source_list, type, NULL)) == 0) {
-		g_warning ("Could not get any sources of type %s.", name);
-		return NULL;
-	}
-
-	primary = e_source_list_peek_source_any (source_list);
-
-	if ((cal = e_cal_new (primary, type)) == NULL) {
-		g_warning ("Could not create %s.", name);
-		g_object_unref (source_list);
-		return NULL;
-	}
-
-	e_cal_open (cal, TRUE, NULL);
-	g_object_unref (primary);
-	g_object_unref (source_list);
-
-	return cal;
-}
-
 static void
 pst_import_import (PstImporter *m,
                    GCancellable *cancellable,
                    GError **error)
 {
-	if (GPOINTER_TO_INT (g_datalist_get_data (&m->target->data, "pst-do-addr"))) {
-		/* Hack - grab the first address book we can find
-		   TODO - add a selection mechanism in get_widget */
-		ESource *primary;
-		ESourceList *source_list;
+	pst_import_file (m);
+}
 
-		if (e_book_get_addressbooks (&source_list, NULL)) {
-			primary = e_source_list_peek_source_any (source_list);
+static void
+count_items (PstImporter *m, pst_desc_tree *topitem)
+{
+	pst_desc_tree *d_ptr;
 
-			if ((m->addressbook = e_book_new (primary,NULL))) {
-				e_book_open (m->addressbook, TRUE, NULL);
-				g_object_unref (primary);
-				g_object_unref (source_list);
-			} else {
-				g_warning ("Could not create EBook.");
-			}
+	m->position = 3;
+	m->total = 5;
+	d_ptr = topitem->child;
+
+	/* Walk through folder tree */
+	while (d_ptr != NULL) {
+		m->total++;
+
+		if (d_ptr->child != NULL) {
+			d_ptr = d_ptr->child;
+		} else if (d_ptr->next != NULL) {
+			d_ptr = d_ptr->next;
 		} else {
-			g_warning ("Could not get address books.");
+			while (d_ptr != topitem && d_ptr->next == NULL) {
+				d_ptr = d_ptr->parent;
+			}
+
+			if (d_ptr == topitem)
+				break;
+
+			d_ptr = d_ptr->next;
 		}
 	}
-
-	if (GPOINTER_TO_INT (g_datalist_get_data (&m->target->data, "pst-do-appt"))) {
-		m->calendar = open_ecal (E_CAL_SOURCE_TYPE_EVENT, "calendar");
-	}
-
-	if (GPOINTER_TO_INT (g_datalist_get_data (&m->target->data, "pst-do-task"))) {
-		m->tasks = open_ecal (E_CAL_SOURCE_TYPE_TODO, "task list");
-	}
-
-	if (GPOINTER_TO_INT (g_datalist_get_data (&m->target->data, "pst-do-journal"))) {
-		m->journal = open_ecal (E_CAL_SOURCE_TYPE_JOURNAL, "journal");
-	}
-
-	pst_import_file (m);
-
-/* FIXME: Crashes often in here.
-	if (m->addressbook) {
-		g_object_unref (m->addressbook);
-	}
-
-	if (m->calendar) {
-		g_object_unref (m->calendar);
-	}
-
-	if (m->tasks) {
-		g_object_unref (m->tasks);
-	}
-
-	if (m->journal) {
-		g_object_unref (m->journal);
-	}
-*/
 }
 
 static void
@@ -460,14 +611,11 @@ pst_import_file (PstImporter *m)
 	EShell *shell;
 	EShellBackend *shell_backend;
 	EMailSession *session;
-	GCancellable *cancellable;
 	gint ret;
 	gchar *filename;
 	pst_item *item = NULL;
 	pst_desc_tree *d_ptr;
 
-	cancellable = e_activity_get_cancellable (m->base.activity);
-
 	/* XXX Dig up the EMailSession from the default EShell.
 	 *     Since the EImport framework doesn't allow for user
 	 *     data, I don't see how else to get to it. */
@@ -476,46 +624,47 @@ pst_import_file (PstImporter *m)
 	session = e_mail_backend_get_session (E_MAIL_BACKEND (shell_backend));
 
 	filename = g_filename_from_uri (((EImportTargetURI *) m->target)->uri_src, NULL, NULL);
-	m->parent_uri = g_strdup (((EImportTargetURI *) m->target)->uri_dest); /* Destination folder, was set in our widget */
+	m->folder_uri = g_strdup (((EImportTargetURI *) m->target)->uri_dest); /* Destination folder, was set in our widget */
 
-	camel_operation_push_message (NULL, _("Importing '%s'"), filename);
+	camel_operation_push_message (m->cancellable, _("Importing '%s'"), filename);
 
 	if (GPOINTER_TO_INT (g_datalist_get_data (&m->target->data, "pst-do-mail"))) {
 		e_mail_session_uri_to_folder_sync (
-			session, m->parent_uri, CAMEL_STORE_FOLDER_CREATE,
-			cancellable, &m->base.error);
+			session, m->folder_uri, CAMEL_STORE_FOLDER_CREATE,
+			m->cancellable, &m->base.error);
 	}
 
 	ret = pst_init (&m->pst, filename);
 
 	if (ret < 0) {
 		g_free (filename);
-		camel_operation_pop_message (NULL);
+		camel_operation_pop_message (m->cancellable);
 		return;
 	}
 
 	g_free (filename);
 
-	camel_operation_progress (NULL, 1);
+	camel_operation_progress (m->cancellable, 1);
 
 	if ((item = pst_parse_item (&m->pst, m->pst.d_head, NULL)) == NULL) {
 		pst_error_msg ("Could not get root record");
 		return;
 	}
 
-	camel_operation_progress (NULL, 2);
+	camel_operation_progress (m->cancellable, 2);
 
 	if ((d_ptr = pst_getTopOfFolders (&m->pst, item)) == NULL) {
 		pst_error_msg ("Top of folders record not found. Cannot continue");
 		return;
 	}
 
-	camel_operation_progress (NULL, 3);
+	camel_operation_progress (m->cancellable, 3);
+	count_items (m, d_ptr);
 	pst_import_folders (m, d_ptr);
 
-	camel_operation_progress (NULL, 4);
+	camel_operation_progress (m->cancellable, 100);
 
-	camel_operation_pop_message (NULL);
+	camel_operation_pop_message (m->cancellable);
 
 	pst_freeItem (item);
 
@@ -524,49 +673,78 @@ pst_import_file (PstImporter *m)
 static void
 pst_import_folders (PstImporter *m, pst_desc_tree *topitem)
 {
+	CamelOperation *co = CAMEL_OPERATION (m->cancellable);
+	GHashTable *node_to_folderuri; /* pointers of hierarchy nodes, to them associated folder uris */
 	pst_desc_tree *d_ptr;
-	gchar *seperator;
 
+	node_to_folderuri = g_hash_table_new_full (g_direct_hash, g_direct_equal, NULL, g_free);
 	d_ptr = topitem->child;
 
-	/* Walk through folder tree */
-	while (d_ptr != NULL && (camel_operation_cancel_check (NULL) == FALSE)) {
+	if (topitem)
+		g_hash_table_insert (node_to_folderuri, topitem, g_strdup (m->folder_uri));
 
-		pst_process_item (m, d_ptr);
+	/* Walk through folder tree */
+	while (d_ptr != NULL && (camel_operation_cancel_check (co) == FALSE)) {
+		gchar *previous_folder = NULL;
+
+		m->position++;
+		camel_operation_progress (m->cancellable, 100 * m->position / m->total);
+
+		pst_process_item (m, d_ptr, &previous_folder);
 
 		if (d_ptr->child != NULL) {
-			g_free (m->parent_uri);
-			m->parent_uri = g_strdup (m->folder_uri);
+			if (m->folder) {
+				g_object_unref (m->folder);
+				m->folder = NULL;
+			}
+
+			g_return_if_fail (m->folder_uri != NULL);
+			g_hash_table_insert (node_to_folderuri, d_ptr, g_strdup (m->folder_uri));
+
 			d_ptr = d_ptr->child;
 		} else if (d_ptr->next != NULL) {
+			/* for cases where there is an empty folder node, with no subnodes */
+			if (previous_folder) {
+				g_free (m->folder_uri);
+				m->folder_uri = previous_folder;
+				previous_folder = NULL;
+			}
+
 			d_ptr = d_ptr->next;
 		} else {
 			while (d_ptr != topitem && d_ptr->next == NULL) {
-				if (m->folder_uri) {
-					g_free (m->folder_uri);
+				if (m->folder) {
+					g_object_unref (m->folder);
+					m->folder = NULL;
 				}
 
-				m->folder_uri = g_strdup (m->parent_uri);
-				seperator = g_strrstr (m->parent_uri, "/");
-
-				if (seperator != NULL) {
-					*seperator = '\0'; /* Truncate uri */
-				}
+				g_free (m->folder_uri);
+				m->folder_uri = NULL;
 
 				d_ptr = d_ptr->parent;
 
+				if (d_ptr && d_ptr != topitem) {
+					m->folder_uri = g_strdup (g_hash_table_lookup (node_to_folderuri, d_ptr->parent));
+					g_return_if_fail (m->folder_uri != NULL);
+				}
 			}
+
 			if (d_ptr == topitem) {
-				return;
+				g_free (previous_folder);
+				break;
 			}
 
 			d_ptr = d_ptr->next;
 		}
+
+		g_free (previous_folder);
 	}
+
+	g_hash_table_destroy (node_to_folderuri);
 }
 
 static void
-pst_process_item (PstImporter *m, pst_desc_tree *d_ptr)
+pst_process_item (PstImporter *m, pst_desc_tree *d_ptr, gchar **previous_folder)
 {
 	pst_item *item = NULL;
 
@@ -585,56 +763,39 @@ pst_process_item (PstImporter *m, pst_desc_tree *d_ptr)
 	}
 
 	if (item->folder != NULL) {
+		if (previous_folder)
+			*previous_folder = g_strdup (m->folder_uri);
 		pst_process_folder (m, item);
-		camel_operation_push_message (
-			NULL, _("Importing '%s'"), item->file_as.str);
 	} else {
-		if (m->folder_count && (m->current_item < m->folder_count)) {
-			camel_operation_progress (NULL, (m->current_item * 100) / m->folder_count);
-		} else {
-			camel_operation_progress (NULL, 100);
-		}
-
-		if (item->email != NULL &&
-			(item->type == PST_TYPE_NOTE || item->type == PST_TYPE_REPORT)) {
-
-			if (GPOINTER_TO_INT (g_datalist_get_data (&m->target->data, "pst-do-mail")))
-				pst_process_email (m, item);
-
-		} else if (item->contact && item->type == PST_TYPE_CONTACT) {
-
-			if (m->addressbook && GPOINTER_TO_INT (g_datalist_get_data (&m->target->data, "pst-do-addr"))) {
+		switch (item->type) {
+		case PST_TYPE_CONTACT:
+			if (item->contact && m->addressbook && GPOINTER_TO_INT (g_datalist_get_data (&m->target->data, "pst-do-addr")))
 				pst_process_contact (m, item);
-			}
-
-		} else if (item->type == PST_TYPE_APPOINTMENT && item->appointment) {
-
-			if (m->calendar && GPOINTER_TO_INT (g_datalist_get_data (&m->target->data, "pst-do-appt"))) {
+			break;
+		case PST_TYPE_APPOINTMENT:
+			if (item->appointment && m->calendar && GPOINTER_TO_INT (g_datalist_get_data (&m->target->data, "pst-do-appt")))
 				pst_process_appointment (m, item);
-			}
-
-		} else if (item->type == PST_TYPE_TASK && item->appointment) {
-
-			if (m->tasks && GPOINTER_TO_INT (g_datalist_get_data (&m->target->data, "pst-do-task"))) {
+			break;
+		case PST_TYPE_TASK:
+			if (item->appointment && m->tasks && GPOINTER_TO_INT (g_datalist_get_data (&m->target->data, "pst-do-task")))
 				pst_process_task (m, item);
-			}
-
-		} else if (item->type == PST_TYPE_JOURNAL && item->appointment) {
-
-			if (m->journal && GPOINTER_TO_INT (g_datalist_get_data (&m->target->data, "pst-do-journal"))) {
+			break;
+		case PST_TYPE_JOURNAL:
+			if (item->appointment && m->journal && GPOINTER_TO_INT (g_datalist_get_data (&m->target->data, "pst-do-journal")))
 				pst_process_journal (m, item);
-			}
-
+			break;
+		case PST_TYPE_NOTE:
+		case PST_TYPE_SCHEDULE:
+		case PST_TYPE_REPORT:
+			if (item->email && GPOINTER_TO_INT (g_datalist_get_data (&m->target->data, "pst-do-mail")))
+				pst_process_email (m, item);
+			break;
 		}
 
 		m->current_item++;
 	}
 
 	pst_freeItem (item);
-
-	if (d_ptr->next == NULL) {
-		camel_operation_pop_message (NULL);
-	}
 }
 
 /**
@@ -694,7 +855,6 @@ pst_process_folder (PstImporter *m, pst_item *item)
 {
 	gchar *uri;
 	g_free (m->folder_name);
-	g_free (m->folder_uri);
 
 	if (item->file_as.str != NULL) {
 		m->folder_name = foldername_to_utf8 (item->file_as.str);
@@ -703,7 +863,8 @@ pst_process_folder (PstImporter *m, pst_item *item)
 		m->folder_name = g_strdup ("unknown_name");
 	}
 
-	uri = g_strjoin ("/", m->parent_uri, m->folder_name, NULL);
+	uri = g_strjoin ("/", m->folder_uri, m->folder_name, NULL);
+	g_free (m->folder_uri);
 	m->folder_uri = uri;
 
 	if (m->folder) {
@@ -728,13 +889,10 @@ pst_create_folder (PstImporter *m)
 	EShell *shell;
 	EShellBackend *shell_backend;
 	EMailSession *session;
-	GCancellable *cancellable;
 	const gchar *parent;
 	gchar *dest, *dest_end, *pos;
 	gint dest_len;
 
-	cancellable = e_activity_get_cancellable (m->base.activity);
-
 	/* XXX Dig up the EMailSession from the default EShell.
 	 *     Since the EImport framework doesn't allow for user
 	 *     data, I don't see how else to get to it. */
@@ -745,7 +903,7 @@ pst_create_folder (PstImporter *m)
 	parent = ((EImportTargetURI *) m->target)->uri_dest;
 	dest = g_strdup (m->folder_uri);
 
-	g_assert (g_str_has_prefix (dest, parent));
+	g_return_if_fail (g_str_has_prefix (dest, parent));
 
 	if (m->folder) {
 		g_object_unref (m->folder);
@@ -766,7 +924,7 @@ pst_create_folder (PstImporter *m)
 
 			folder = e_mail_session_uri_to_folder_sync (
 				session, dest, CAMEL_STORE_FOLDER_CREATE,
-				cancellable, &m->base.error);
+				m->cancellable, &m->base.error);
 			if (folder)
 				g_object_unref (folder);
 			else
@@ -780,7 +938,7 @@ pst_create_folder (PstImporter *m)
 	if (!m->base.error)
 		m->folder = e_mail_session_uri_to_folder_sync (
 			session, m->folder_uri, CAMEL_STORE_FOLDER_CREATE,
-			cancellable, &m->base.error);
+			m->cancellable, &m->base.error);
 }
 
 /**
@@ -836,6 +994,8 @@ pst_process_email (PstImporter *m, pst_item *item)
 	CamelMimePart *part;
 	CamelMessageInfo *info;
 	pst_item_attach *attach;
+	gboolean has_attachments;
+	gchar *comp_str = NULL;
 	gboolean success;
 
 	if (m->folder == NULL) {
@@ -844,6 +1004,55 @@ pst_process_email (PstImporter *m, pst_item *item)
 			return;
 	}
 
+	/* stops on the first valid attachment */
+	for (attach = item->attach; attach; attach = attach->next) {
+		if (attach->data.data || attach->i_id)
+			break;
+	}
+
+	has_attachments = attach != NULL;
+
+	if (item->type == PST_TYPE_SCHEDULE && item->appointment) {
+		ECalComponent *comp;
+		icalcomponent *vcal;
+		icalproperty *prop;
+		icalvalue *value;
+		icalproperty_method method;
+
+		comp = e_cal_component_new ();
+		e_cal_component_set_new_vtype (comp, E_CAL_COMPONENT_EVENT);
+		fill_calcomponent (m, item, comp, "meeting-request");
+
+		vcal = e_cal_util_new_top_level ();
+
+		method = ICAL_METHOD_PUBLISH;
+		if (item->ascii_type) {
+			if (g_str_has_prefix (item->ascii_type, "IPM.Schedule.Meeting.Request"))
+				method = ICAL_METHOD_REQUEST;
+			else if (g_str_has_prefix (item->ascii_type, "IPM.Schedule.Meeting.Canceled"))
+				method = ICAL_METHOD_CANCEL;
+			else if (g_str_has_prefix (item->ascii_type, "IPM.Schedule.Meeting.Resp."))
+				method = ICAL_METHOD_REPLY;
+		}
+
+		prop = icalproperty_new (ICAL_METHOD_PROPERTY);
+		value = icalvalue_new_method (method);
+		icalproperty_set_value (prop, value);
+		icalcomponent_add_property (vcal, prop);
+
+		icalcomponent_add_component (vcal, icalcomponent_new_clone (e_cal_component_get_icalcomponent (comp)));
+
+		comp_str = icalcomponent_as_ical_string_r (vcal);
+
+		icalcomponent_free (vcal);
+		g_object_unref (comp);
+
+		if (comp_str && !*comp_str) {
+			g_free (comp_str);
+			comp_str = NULL;
+		}
+	}
+
 	camel_folder_freeze (m->folder);
 
 	msg = camel_mime_message_new ();
@@ -918,7 +1127,7 @@ pst_process_email (PstImporter *m, pst_item *item)
 
 	mp = camel_multipart_new ();
 
-	if (item->attach != NULL) {
+	if (has_attachments) {
 
 		camel_data_wrapper_set_mime_type (CAMEL_DATA_WRAPPER (mp), "multipart/mixed");
 
@@ -954,6 +1163,13 @@ pst_process_email (PstImporter *m, pst_item *item)
 		g_object_unref (part);
 	}
 
+	if (comp_str) {
+		part = camel_mime_part_new ();
+		camel_mime_part_set_content (part, comp_str, strlen (comp_str), "text/calendar");
+		camel_multipart_add_part (mp, part);
+		g_object_unref (part);
+	}
+
 	for (attach = item->attach; attach; attach = attach->next) {
 		if (attach->data.data || attach->i_id) {
 			part = attachment_to_part (m, attach);
@@ -996,8 +1212,10 @@ pst_process_email (PstImporter *m, pst_item *item)
 	camel_folder_synchronize_sync (m->folder, FALSE, NULL, NULL);
 	camel_folder_thaw (m->folder);
 
+	g_free (comp_str);
+
 	if (!success) {
-		g_critical ("Exception!");
+		g_debug ("%s: Exception!", G_STRFUNC);
 		return;
 	}
 
@@ -1030,7 +1248,7 @@ contact_set_address (EContact *contact, EContactField id, gchar *address, gchar
 		if (po_box) {
 			eaddress->po = g_strdup (po_box);
 		}
-		//eaddress->ext =
+		/* eaddress->ext = */
 
 		if (street) {
 			eaddress->street = g_strdup (street);
@@ -1082,6 +1300,8 @@ pst_process_contact (PstImporter *m, pst_item *item)
 	pst_item_contact *c;
 	EContact *ec;
 	GString *notes;
+	gchar *uid = NULL;
+	GError *error = NULL;
 
 	c = item->contact;
 	notes = g_string_sized_new (2048);
@@ -1218,9 +1438,18 @@ pst_process_contact (PstImporter *m, pst_item *item)
 	contact_set_string (ec, E_CONTACT_NOTE, notes->str);
 	g_string_free (notes, TRUE);
 
-	e_book_add_contact (m->addressbook, ec, NULL);
-	g_object_unref (ec);
+	if (!e_book_client_add_contact_sync (m->addressbook, ec, &uid, NULL, &error))
+		uid = NULL;
 
+	g_object_unref (ec);
+	g_free (uid);
+
+	if (error != NULL) {
+		g_warning (
+			"%s: Failed to add contact: %s",
+			G_STRFUNC, error->message);
+		g_error_free (error);
+	}
 }
 
 /**
@@ -1246,7 +1475,7 @@ get_ical_date (FILETIME *date, gboolean is_date)
 }
 
 static void
-set_cal_attachments (ECal *cal, ECalComponent *ec, PstImporter *m, pst_item_attach *attach)
+set_cal_attachments (ECalClient *cal, ECalComponent *ec, PstImporter *m, pst_item_attach *attach)
 {
 	GSList *list = NULL;
 	const gchar *uid;
@@ -1257,7 +1486,7 @@ set_cal_attachments (ECal *cal, ECalComponent *ec, PstImporter *m, pst_item_atta
 	}
 
 	e_cal_component_get_uid (ec, &uid);
-	store_dir = g_filename_from_uri (e_cal_get_local_attachment_store (cal), NULL, NULL);
+	store_dir = g_filename_from_uri (e_cal_client_get_local_attachment_store (cal), NULL, NULL);
 
 	while (attach != NULL) {
 		const gchar * orig_filename;
@@ -1398,14 +1627,14 @@ fill_calcomponent (PstImporter *m, pst_item *item, ECalComponent *ec, const gcha
 	if (a->start) {
 		tt_start = get_ical_date (a->start, a->all_day);
 		dt_start.value = &tt_start;
-		dt_start.tzid = NULL;
+		dt_start.tzid = a->timezonestring.str;
 		e_cal_component_set_dtstart (ec, &dt_start);
 	}
 
 	if (a->end) {
 		tt_end = get_ical_date (a->end, a->all_day);
 		dt_end.value = &tt_end;
-		dt_end.tzid = NULL;
+		dt_end.tzid = a->timezonestring.str;
 		e_cal_component_set_dtend (ec, &dt_end);
 	}
 
@@ -1414,7 +1643,7 @@ fill_calcomponent (PstImporter *m, pst_item *item, ECalComponent *ec, const gcha
 			e_cal_component_set_status (ec, ICAL_STATUS_TENTATIVE);
 			break;
 		case PST_FREEBUSY_FREE:
-			// mark as transparent and as confirmed
+			/* mark as transparent and as confirmed */
 			e_cal_component_set_transparency (ec, E_CAL_COMPONENT_TRANSP_TRANSPARENT);
 		case PST_FREEBUSY_BUSY:
 		case PST_FREEBUSY_OUT_OF_OFFICE:
@@ -1499,12 +1728,55 @@ fill_calcomponent (PstImporter *m, pst_item *item, ECalComponent *ec, const gcha
 		e_cal_component_set_rrule_list (ec, &recur_list);
 	}
 
+	if (item->type == PST_TYPE_SCHEDULE && item->email && item->ascii_type) {
+		const gchar *organizer, *organizer_addr, *attendee, *attendee_addr;
+
+		if (g_str_has_prefix (item->ascii_type, "IPM.Schedule.Meeting.Resp.")) {
+			organizer = item->email->outlook_recipient_name.str;
+			organizer_addr = item->email->outlook_recipient.str;
+			attendee = item->email->outlook_sender_name.str;
+			attendee_addr = item->email->outlook_sender.str;
+		} else {
+			organizer = item->email->outlook_sender_name.str;
+			organizer_addr = item->email->outlook_sender.str;
+			attendee = item->email->outlook_recipient_name.str;
+			attendee_addr = item->email->outlook_recipient.str;
+		}
+
+		if (organizer || organizer_addr) {
+			ECalComponentOrganizer org = { 0 };
+
+			org.value = organizer_addr;
+			org.cn = organizer;
+
+			e_cal_component_set_organizer (ec, &org);
+		}
+
+		if (attendee || attendee_addr) {
+			ECalComponentAttendee att = { 0 };
+			GSList *attendees;
+
+			att.value = attendee_addr;
+			att.cn = attendee;
+			att.cutype = ICAL_CUTYPE_INDIVIDUAL;
+			att.status = ICAL_PARTSTAT_NEEDSACTION;
+			att.role = ICAL_ROLE_REQPARTICIPANT;
+			att.rsvp = TRUE;
+
+			attendees = g_slist_append (NULL, &att);
+			e_cal_component_set_attendee_list (ec, attendees);
+			g_slist_free (attendees);
+		}
+	}
+
+	e_cal_component_commit_sequence	 (ec);
 }
 
 static void
-pst_process_component (PstImporter *m, pst_item *item, const gchar *comp_type, ECal *cal)
+pst_process_component (PstImporter *m, pst_item *item, const gchar *comp_type, ECalClient *cal)
 {
 	ECalComponent *ec;
+	gchar *uid = NULL;
 	GError *error = NULL;
 
 	g_return_if_fail (item->appointment != NULL);
@@ -1515,12 +1787,13 @@ pst_process_component (PstImporter *m, pst_item *item, const gchar *comp_type, E
 	fill_calcomponent (m, item, ec, comp_type);
 	set_cal_attachments (cal, ec, m, item->attach);
 
-	if (!e_cal_create_object (cal, e_cal_component_get_icalcomponent (ec), NULL, &error)) {
+	if (!e_cal_client_create_object_sync (cal, e_cal_component_get_icalcomponent (ec), &uid, NULL, &error)) {
+		uid = NULL;
 		g_warning ("Creation of %s failed: %s", comp_type, error ? error->message : "Unknown error");
 	}
 
 	g_object_unref (ec);
-
+	g_free (uid);
 	if (error)
 		g_error_free (error);
 }
@@ -1563,7 +1836,16 @@ pst_import_imported (PstImporter *m)
 static void
 pst_import_free (PstImporter *m)
 {
-//	pst_close (&m->pst);
+	/* pst_close (&m->pst); */
+	if (m->addressbook)
+		g_object_unref (m->addressbook);
+	if (m->calendar)
+		g_object_unref (m->calendar);
+	if (m->tasks)
+		g_object_unref (m->tasks);
+	if (m->journal)
+		g_object_unref (m->journal);
+
 	g_object_unref (m->cancellable);
 
 	g_free (m->status_what);
@@ -1574,7 +1856,6 @@ pst_import_free (PstImporter *m)
 
 	g_free (m->folder_name);
 	g_free (m->folder_uri);
-	g_free (m->parent_uri);
 
 	g_object_unref (m->import);
 }
@@ -1619,11 +1900,10 @@ pst_status (CamelOperation *op, const gchar *what, gint pc, gpointer data)
 	g_mutex_unlock (importer->status_lock);
 }
 
-static gint
+static void
 pst_import (EImport *ei, EImportTarget *target)
 {
 	PstImporter *m;
-	gint id;
 
 	m = mail_msg_new (&pst_import_info);
 	g_datalist_set_data (&target->data, "pst-msg", m);
@@ -1631,7 +1911,6 @@ pst_import (EImport *ei, EImportTarget *target)
 	g_object_ref (m->import);
 	m->target = target;
 
-	m->parent_uri = NULL;
 	m->folder_name = NULL;
 	m->folder_uri = NULL;
 
@@ -1639,6 +1918,7 @@ pst_import (EImport *ei, EImportTarget *target)
 	m->calendar = NULL;
 	m->tasks = NULL;
 	m->journal = NULL;
+	m->waiting_open = 0;
 
 	m->status_timeout_id = g_timeout_add (100, pst_status_timeout, m);
 	/*m->status_timeout_id = NULL;*/
@@ -1649,11 +1929,7 @@ pst_import (EImport *ei, EImportTarget *target)
 		m->cancellable, "status",
 		G_CALLBACK (pst_status), m);
 
-	id = m->base.seq;
-
-	mail_msg_unordered_push (m);
-
-	return id;
+	pst_prepare_run (m);
 }
 
 /* Start the main import operation */
