@@ -118,23 +118,29 @@ org_gnome_vcard_inline_decode (VCardInlinePObject *vcard_object,
 }
 
 static void
-org_gnome_vcard_inline_client_loaded_cb (GObject *source_object, GAsyncResult *result, gpointer user_data)
+org_gnome_vcard_inline_client_loaded_cb (GObject *source_object,
+                                         GAsyncResult *result,
+                                         gpointer user_data)
 {
+	ESource *source = E_SOURCE (source_object);
 	EClient *client = NULL;
 	EBookClient *book_client;
 	GSList *contact_list = user_data, *iter;
 	GError *error = NULL;
 
-	if (!e_client_utils_open_new_finish (E_SOURCE (source_object), result, &client, &error))
-		client = NULL;
+	e_client_utils_open_new_finish (source, result, &client, &error);
 
-	if (client == NULL) {
-		g_debug ("%s: Failed to open book client: %s", G_STRFUNC, error ? error->message : "Unknown error");
-		if (error)
-			g_error_free (error);
+	if (error != NULL) {
+		g_warn_if_fail (client == NULL);
+		g_warning (
+			"%s: Failed to open book client: %s",
+			G_STRFUNC, error->message);
+		g_error_free (error);
 		goto exit;
 	}
 
+	g_return_if_fail (E_IS_BOOK_CLIENT (client));
+
 	book_client = E_BOOK_CLIENT (client);
 
 	for (iter = contact_list; iter != NULL; iter = iter->next) {
@@ -313,6 +319,7 @@ org_gnome_vcard_inline_format (gpointer ep, EMFormatHookTarget *target)
 {
 	VCardInlinePObject *vcard_object;
 	gchar *classid;
+	gchar *content;
 
 	classid = g_strdup_printf (
 		"org-gnome-vcard-inline-display-%d",
@@ -332,8 +339,9 @@ org_gnome_vcard_inline_format (gpointer ep, EMFormatHookTarget *target)
 
 	e_book_client_get_sources (&vcard_object->source_list, NULL);
 
-	camel_stream_printf (
-		target->stream, "<object classid=%s></object>", classid);
+	content = g_strdup_printf ("<object classid=%s></object>", classid);
+	camel_stream_write_string (target->stream, content, NULL, NULL);
+	g_free (content);
 
 	g_free (classid);
 }
