@@ -137,10 +137,11 @@ e_calendar_init (ECalendar *cal)
 
 	/* Create the small font. */
 
-	small_font_desc =
-		pango_font_description_copy (gtk_widget_get_style (GTK_WIDGET (cal))->font_desc);
-	pango_font_description_set_size (small_font_desc,
-					 E_CALENDAR_SMALL_FONT_PTSIZE * PANGO_SCALE);
+	small_font_desc = pango_font_description_copy (
+		gtk_widget_get_style (GTK_WIDGET (cal))->font_desc);
+	pango_font_description_set_size (
+		small_font_desc,
+		E_CALENDAR_SMALL_FONT_PTSIZE * PANGO_SCALE);
 
 	canvas_group = GNOME_CANVAS_GROUP (GNOME_CANVAS (cal)->root);
 
@@ -658,7 +659,8 @@ e_calendar_set_focusable (ECalendar *cal, gboolean focusable)
 		gtk_widget_set_can_focus (next_widget, TRUE);
 	}
 	else {
-		if (gtk_widget_has_focus (GTK_WIDGET (cal)) || e_calendar_button_has_focus (cal)) {
+		if (gtk_widget_has_focus (GTK_WIDGET (cal)) ||
+		    e_calendar_button_has_focus (cal)) {
 			toplevel = gtk_widget_get_toplevel (widget);
 			if (toplevel)
 				gtk_widget_grab_focus (toplevel);
