@@ -21,7 +21,9 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
 
 #include <gtk/gtk.h>
 
