@@ -21,7 +21,9 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
 
 #include "e-util/e-util.h"
 
@@ -31,7 +33,8 @@
 static gint esms_get_row_count (ESelectionModelArray *esma);
 
 G_DEFINE_TYPE (
-	ESelectionModelSimple, e_selection_model_simple,
+	ESelectionModelSimple,
+	e_selection_model_simple,
 	E_SELECTION_MODEL_ARRAY_TYPE)
 
 static void
@@ -41,12 +44,11 @@ e_selection_model_simple_init (ESelectionModelSimple *selection)
 }
 
 static void
-e_selection_model_simple_class_init (ESelectionModelSimpleClass *klass)
+e_selection_model_simple_class_init (ESelectionModelSimpleClass *class)
 {
 	ESelectionModelArrayClass *esma_class;
 
-	esma_class                = E_SELECTION_MODEL_ARRAY_CLASS(klass);
-
+	esma_class = E_SELECTION_MODEL_ARRAY_CLASS (class);
 	esma_class->get_row_count = esms_get_row_count;
 }
 
@@ -65,48 +67,53 @@ e_selection_model_simple_new (void)
 
 void
 e_selection_model_simple_set_row_count (ESelectionModelSimple *esms,
-					gint row_count)
+                                        gint row_count)
 {
 	if (esms->row_count != row_count) {
-		ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY(esms);
+		ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY (esms);
 		if (esma->eba)
-			g_object_unref(esma->eba);
+			g_object_unref (esma->eba);
 		esma->eba = NULL;
 		esma->selected_row = -1;
 		esma->selected_range_end = -1;
 	}
+
 	esms->row_count = row_count;
 }
 
 static gint
 esms_get_row_count (ESelectionModelArray *esma)
 {
-	ESelectionModelSimple *esms = E_SELECTION_MODEL_SIMPLE(esma);
+	ESelectionModelSimple *esms = E_SELECTION_MODEL_SIMPLE (esma);
 
 	return esms->row_count;
 }
 
-void      e_selection_model_simple_insert_rows         (ESelectionModelSimple *esms,
-							gint                    row,
-							gint                    count)
+void
+e_selection_model_simple_insert_rows (ESelectionModelSimple *esms,
+                                      gint row,
+                                      gint count)
 {
 	esms->row_count += count;
-	e_selection_model_array_insert_rows (E_SELECTION_MODEL_ARRAY(esms), row, count);
+	e_selection_model_array_insert_rows (
+		E_SELECTION_MODEL_ARRAY (esms), row, count);
 }
 
 void
-e_selection_model_simple_delete_rows          (ESelectionModelSimple *esms,
-					       gint                    row,
-					       gint                    count)
+e_selection_model_simple_delete_rows (ESelectionModelSimple *esms,
+                                      gint row,
+                                      gint count)
 {
 	esms->row_count -= count;
-	e_selection_model_array_delete_rows (E_SELECTION_MODEL_ARRAY(esms), row, count);
+	e_selection_model_array_delete_rows (
+		E_SELECTION_MODEL_ARRAY (esms), row, count);
 }
 
 void
-e_selection_model_simple_move_row            (ESelectionModelSimple *esms,
-					      gint                    old_row,
-					      gint                    new_row)
+e_selection_model_simple_move_row (ESelectionModelSimple *esms,
+                                   gint old_row,
+                                   gint new_row)
 {
-	e_selection_model_array_move_row (E_SELECTION_MODEL_ARRAY(esms), old_row, new_row);
+	e_selection_model_array_move_row (
+		E_SELECTION_MODEL_ARRAY (esms), old_row, new_row);
 }
