@@ -20,7 +20,9 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
 
 #include <gdk/gdkkeysyms.h>
 
@@ -744,7 +746,8 @@ e_selection_model_key_press (ESelectionModel *selection,
 			gint cursor_col = e_selection_model_cursor_col (selection);
 
 			row = e_sorter_sorted_to_model (selection->sorter, row);
-			e_selection_model_select_as_key_press (selection, row, cursor_col, key->state);
+			e_selection_model_select_as_key_press (
+				selection, row, cursor_col, key->state);
 			return TRUE;
 		}
 		break;
@@ -755,7 +758,8 @@ e_selection_model_key_press (ESelectionModel *selection,
 			gint cursor_col = e_selection_model_cursor_col (selection);
 
 			row = e_sorter_sorted_to_model (selection->sorter, row);
-			e_selection_model_select_as_key_press (selection, row, cursor_col, key->state);
+			e_selection_model_select_as_key_press (
+				selection, row, cursor_col, key->state);
 			return TRUE;
 		}
 		break;
