@@ -19,9 +19,12 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "e-web-view-preview.h"
 
-#include <config.h>
 #include <string.h>
 #include <glib/gi18n-lib.h>
 
