@@ -21,7 +21,9 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
 
 #include <string.h>
 
@@ -509,7 +511,7 @@ eti_get_caption (AtkTable *table)
 	return NULL;
 }
 
-static G_CONST_RETURN gchar *
+static const gchar *
 eti_get_column_description (AtkTable *table,
 			    gint column)
 {
@@ -544,7 +546,7 @@ eti_get_column_header (AtkTable *table, gint column)
 	return atk_obj;
 }
 
-static G_CONST_RETURN gchar *
+static const gchar *
 eti_get_row_description (AtkTable *table,
 			 gint row)
 {
@@ -654,7 +656,10 @@ table_remove_row_selection (AtkTable *table, gint row)
 
 	if (!atk_table_is_row_selected (table, row))
 		return TRUE;
-	e_selection_model_toggle_single_row (item->selection, view_to_model_row (item, row));
+
+	e_selection_model_toggle_single_row (
+		item->selection, view_to_model_row (item, row));
+
 	return TRUE;
 }
 
@@ -756,7 +761,7 @@ eti_rows_deleted (ETableModel * model, gint row, gint count,
 		}
 	}
 	g_signal_emit_by_name (table_item, "visible-data-changed");
-	eti_a11y_reset_focus_object ((GalA11yETableItem *)table_item, item, TRUE);
+	eti_a11y_reset_focus_object ((GalA11yETableItem *) table_item, item, TRUE);
 }
 
 static void
